$TITLE Core model file. SAINT 1.01 CGE modeling system


$ONTEXT
This file is the core model file of the CGE model SAINT 1.01 documented in:
SAINT 1.01
A Standard CGE model for Advanced Analysis of Indirect Taxation
Manual
Lars Bohlin
University of rebro

The documentation could be downloaded from:
http://www.natskolan.se/research/saint.htm

The model is a development of the IFPRI/TMD Standard CGE model documented in:
Lofgren, Hans, Rebecca Lee Harris, and Sherman Robinson, with the
assistance of Moataz El-Said and Marcelle Thomas. 2002. A Standard
Computable General Equilibrium (CGE) Model in GAMS. Microcomputers in
Policy Research, Vol. 5. Washington, D.C.: IFPRI.

The file SAINTBASE.GMS consists of the following segments (with
searchable headings):

1. MAIN DIFFERENCES FROM THE STANDARD MODEL


2. SET DECLARATIONS

All sets are declared together with some parameters that are used in the
options and database sections.
(No sets are defined here, they are defined in the indatafile).

3. PARAMETER DECLARATIONS

All model parameters (including those used to initialize variables)
are DECLARED.

4. OPTIONS

In this section all options are defined
This is the only section where you have to make changes in this file.

5. DATABASE

Include file with data for a selected country is read in.
In the include file SAM, trade margins and indirekt tax parameters are declared
and defined.
In this file, the SAM structure is adjusted to fit the model structure.

Error messages created by the optional include file diagnostics
alert the user to missing data or other inconsistecies with the model.

Moreover the optional datamanipulation procedures are included here. However to
activate them you just have to change the settings in the 3. OPTIONS section


6. CALIBRATION

All model parameters (including those used to initialize variables)
are DEFINED.


7. VARIABLE DECLARATIONS

All model variables are declared.


8. VARIABLE DEFINITIONS

All model variables are initialized.


9. EQUATION DECLARATIONS

The model equations are declared. They are divided into the following
four blocks: "Price block", "Production and trade block", "Institution
block", and "System constraint block".


10. EQUATION DEFINITIONS

The model equations are defined. They are divided into the same four
blocks as under 7.


11. MODEL DEFINITION

The model (a set of equations most of which are linked to variables)
is defined.


12. FIXING VARIABLES NOT IN MODEL AT ZERO

13. MODEL CLOSURE

Variables not included in the model are fixed. Macro and micro closure
rules are selected by fixing selected variables.




14. SOLUTION STATEMENT

The model is solved for the base with some optional tests of robustness


15. SOLUTION REPORTS

$offtext










$ONSYMLIST ONSYMXREF OFFUPPER
*The command on the next line makes it possible to use xllink in if statements
$libinclude xllink
*$OFFSYMLIST OFFSYMXREF
$ONEMPTY
*The dollar control option makes empty data initialization statements
*permissible (e.g. sets without elements or parameters without data)

$ontext
1. MAIN DIFFERENCES FROM THE STANDARD MODEL

The most important differences between this model and the IFPRI model are the
following:

Taxes and Trade margins:
In this model indirect taxes are implemented as value and quanity taxes on
the purchase of commodities. The tax rates are specified not only on the
commodity purchased but also on different purchasers, meaning that purchasers
price of the same commodity differs between actors.
In the same way trade margins are specified on purchaser.

Moreover the trade margins could be specified with both a fix and a marginal
part meaning that it is possible to let marginal and average prices differ. This
gives a possibility to model realistic quantities and marginal costs in cases
of two price tariffs or other situation where a the marginal price differs from
average price. This is in particular important for modelling electricity taxes
since the amount paid for electricity often includes a fix cost which make up
substantial part of the price for small consumers and are negligible for large.

Taxes that are removed compared to the IFPRI Standard Model are vatax and qtax

Perfect substitutability between commodities with different producer:
The IFPRI standard model assume a substitution elasticity between a specific commodity
produced in different activities, thus different producer prices for different
producers are possible. In this model a domestically produced commodity has the
same property regardless of in which industry it is produced and thus the
producer price are the same for all domestic producer of the same commodity.

Technology:
In the standard model all intermediates are treated with leontief technology. In
this model there is an option to choose a subset of intermediate inputs with
substitution possibilities.

Home consumption not allowed:
For reducing model complexity this model do not allow home consumption.
Only marketed commodities is modelled.

Aggregate consumption function:
The aggregate consumption function is a function of wealth not only of income.
This is important in dynamic simulations

Investment block:
A new block of equations is included treating investments.
The purpose of this block is to make the model recursive dynamic.

Data manipulations:
A program to redistribute secondary products
is included in this model.

Since the differences from the standard model is so large most of the code is
changed and there are no specific marks over what peaces of code that are
equivalent with the standard model.


$offtext


*2. SET DECLARATIONS ################################################

$ontext

In this section, all sets are declared.

$offtext

SETS


 AC               global set for model accounts - aggregated microsam accounts
 ACNT(AC)         all elements in AC except TOTAL

 P(AC)            all purchasers
 PNI(P)           all purchasers except investments
 A(PNI)           activities
 AETS(A)          activities included in permit trading
 ANETS(A)         activities not included in permit trading
 PNE(PNI)         all purchasers except exports and investments

 INS(P)           institutions
 INSD(PNI)        domestic institutions
 INSNG(INS)       non-government institutions
 H(INSD)          households

 C(AC)            commodities
 CD(C)            commodities with domestic sales of output
 CDN(C)           commodities without domestic sales of output
 CE(C)            exported commodities
 CEN(C)           non-export commodities
 CM(C)            imported commodities
 CMN(C)           non-imported commodities
 CX(C)            commodities with output
 CTR(C)           commodities used for trade margins
 CGOV(C)          commodities consumed by government
 CLEO(C)          commodities with leontief technology when used as inputs
 CSUBI(C)         commodities with ces technology when used as inputs
 FOSSIL(C)        fossil fuels
 FOSSILPERM(FOSSIL) fossil fuels included in permit trading
 FOSSILNPERM(FOSSIL) fossil fuels not included in permit trading

 CGH              set to define commodity groups in household consumption
 CGA              set to define commodity groups in intermediate use

 F(AC)            factors
 FLAB(F)          labor
 FCAP(F)          capital
 FLAND(F)         natural resources
 FOP(FCAP)        capital that is used to adjustments in SAINTSEC

 INCDAT           set to define used indata
 INCELAS          set to define elasticity settings







 SOLVEIND         solve indicators
 /
 MODEL-STATUS    model status
 SOLVER-STATUS   solver status
 OBJ-VALUE       value of objective function
 NUM-REDEFEQ     number of redefined equations
 /


 PRDELAS prod elasticities
 /
 SIGMASC    elasticity qsc nest
 SIGMASUB   elasticity qsub nest
 SIGMASUBI  elasticity between sustitutables intermediate inputs
 SIGMALAB   elasticity between labour
 SIGMACAP   elasticity between capital
 /

*SIGMAARM is the elasticity of substitution between imports
*and domestic output in domestic demand.
*SIGMACET is the elasticity of transformation for domestic
*marketed output between exports and domestic supplies.
*SIGMAQ is the price elasticity of imports
*SIGMAT is the price elasticity of exports

 TRDELAS  trade elasticities
 /
 SIGMAQ     import elasticity
 SIGMAT     export elasticity
 SIGMAARM   elasticity of substitution in armington equation
 SIGMACET   elasticity of substitution in CET equation
 /



*ALIAS statement to create identical cets
ALIAS
 (AC,ACP)  , (ACNT,ACNTP), (A,AP),  (C,CP)
 (CE,CEP)  , (CM,CMP)    , (CLEO,CLEOP) , (CSUBI,CSUBIP)
 (F,FP)    , (FLAB,FLABP), (FLAND,FLANDP), (FCAP,FCAPP)
 (CGH,CGHP), (INS,INSP), (INSD,INSDP), (H,HP)
 (CTR,CTRP), (CGA,CGAP)
 ;



*3. PARAMETER DECLARATIONS ##########################################
$ontext

This section is divided into the following subsections:
a. parmeters to be used in the options and databas sections
b. Parameters appearing in model equations
c. Parameters used for model calibration (to initialize variables and
   to define model parameters)

In each group, the parameters are declared in alphabetical order.

$offtext



 PARAMETERS
*parmeters to be used in the options and databas sections
 ANETTRADE               Parameter to activate the nettrade procedure
 binvmat(C,A)            the matrix of investments at basic prices
 capdef(C,FCAP)          Parameter to define which goods are included in fcap
 carbshare(fossil)       Content oc CO2 emission in fossil fuels
 CPRODELAS(A,CGA)        elasticity of substitutione within intermediate aggregates
 deprate(A,FCAP)         rate of depeciation for capital good fcap in activity a
 elasfile(INCELAS)       parameter to remined you about your elasticity settings
 fixtm(C,PNI)            fix part of disaggregated trade margins
 fixtminv(C,A)           fix part of disaggregated trade margins on investments
 FIXTMPAR                Parameter to activate the fix trade margin procedure
 FRISCH(H)               Frisch parameter for household LES demand
 indatafile(INCDAT)      parameter to remined you about your indata file
 invpar(A,FCAP)          the "elasticity" of investments with respect to tobin q
 LESELAS1(CGH,H)         Exp'e elasticity of market dem for com group CGH by hhd h
 margprice(C,P)          defining max deviation in purchaser price less taxes from basic price
 margtm(C,PNI)           marginal part of disaggregated trade margins
 margtminv(C,A)          marginal part of disaggregated trade margins on investments
 proddefcsubi(CSUBI,CGA) matrix to define the neststructure of intermediates in prod func
 PRODELAS(A,PRDELAS)     elasticity of substittion in production functions by activity
 PSUP(C)                 initial basic price for commodity c
 returnbal               The value of return when Net asset postition abroad is equal to zero
 SAM(AC,ACP)             standard SAM
 SAMBALCHK(AC)           column minus row total for SAM
 SAMMAN(AC,ACP)          parameter for manipulations in SAM
 scaling                 scaling factor for indata
 SOLVERCHOICE            Parameter to choose between nlp and mcp
 testdefcsubi(CSUBI)     parameter to test that the rows of the proddefcsubi sum to 1
 testdefcsubit(CSUBI)    parameter to test that the rows of the proddefcsubi sum to 1
 testdefcsubitt(CSUBI)   parameter to test that the rows of the proddefcsubi sum to 1
 testhcdef(C)            parameter to test that the rows of the usehcdef sum to 1
 testhcdeft              parameter to test that the rows of the usehcdef sum to 1
 testhcdeftt             parameter to test that the rows of the usehcdef sum to 1
 tminv(C,A)              trade margins on investments
 tmmat(C,P)              disaggregated trade margins
 tobinqpar               parameter to define calibration method for investments
 tqinv(C,A)              disaggregated quantity tax on investments
 tqmat(C,P)              disaggregated quantity tax
 TRADELAS(AC,TRDELAS)    Armington and CET elasticities by commodity
 tvinv(C,A)              disaggregated value tax on investments
 tvmat(C,P)              disaggregated value tax
 usehcdef(C,CGH)         matrix to define the neststructure in consumption
 utilityfunc             define the consumer behaviour
 utilityfuncerr          error in the definition of consumer behaviour
 ;


*Default values of option parameters
*Do not change the following lines, adjustments are to be made in
*the Options section.



 FIXTMPAR       = 0;
 ANETTRADE      = 0;
 SOLVERCHOICE   = 0;
 scaling        = 1;
 tobinqpar      = 0

PARAMETERS

*b. Parameters appearing in model equations================

*Parameters other than tax rates

 alphacap(A)         shift parameter for CES activity production function capital
 alphacga(A,CGA)     shift parameter for ces activity prod func CGA
 alphacgh(H,CGH)     shift parameter in nested ces utility
 alphalab(A)         shift parameter for CES activity production function labour
 alphaq(C)           shift parameter for Armington function
 alphasc(A)          shift parameter for CES activity production function qsc nest
 alphasub(A)         shift parameter for CES activity production function sub nest
 alphasubi(A)        shift parameter for CES activity production function subi
 alphat(C)           shift parameter for CET function
 beta(CGH,H)         marg share of hhd cons on commodity c
 cint(H)             the intercept in the consumption function as share of the wealth of the household
 cwts(C,H)           consumer price index weights
 deltaarm(C)         share parameter for Armington function
 deltacap(FCAP,A)    share parameter for CES act. production function capital
 deltacet(C)         share parameter for CET function
 deltacga(CSUBI,A,CGA) share parameter for ces activity prod func CGA
 deltacgh(H,C,CGH)   share parameter in nested ces utility
 deltalab(FLAB,A)    share parameter for CES act. production function labour
 deltaland(FLAND,A)  share parameter for CES act. production function land
 deltaq(C)           share parameter for import demand function
 deltasc(A)          share parameter for CES activity production function qsc nest
 deltasub(A)         share parameter for CES activity production function sub nest
 deltasubi(A,CGA)    share parameter for CES act. production function intermediates
 deltat(C)           share parameter for export supply function
 factinret           return on foreign assets to be used in saintdynsim.gms
 FAP                 foreign asset position this year
 finin               financial income from abroad in foreign currency
 finout(A)           Share of foreign financial income in total financial income from industry A
 FLP                 foreign liabilities this year
 FNAP                foreign net asset position this year
 ftmq(C,PNI)         fix part of trade margins in quantities of the trade commodity
 ftmqinv(C,A)        fix part of trade margins in quantities of the trade commodity for investments
 gamma(CGH,H)        per-cap subsist cons of marketed com c for hhd h
 ica(C,A)            leontief intermediate input c per unit of aggregate intermediate
 inta(A)             aggregate intermediate input coefficient
 isc(A)              aggregate substitutables coefficient
 iwts(C,A,FCAP)      quantity comodity c in one unit of investment in activity a
 labin(FLAB)         labour income from abroad in foreign currency
 labout(FLAB)        share of foreign labour income in total labour income from domestic activities
 mpc01(INSD)         0-1 par for potential flexing of savings rates
 mpcbar(INSD)        marg prop to consume for dom non-gov inst ins (exog part)
 ppermit             exogenpus price of CO2 permits
 qbarg(C)            exogenous (unscaled) government demand
 qbarinv(C,A,FCAP)   exogenous (unscaled) investment demand by activity
 qdst(C)             inventory investment by sector of origin
 qpermit(A)          domestic supply of CO2 permits per inustry
 return              required rate of returns on investments
 rhoarm(C)           Armington function exponent
 rhocap(A)           CES activity production function exponent capital
 rhocet(C)           CET function exponent
 rhocga(A,CGA)       ces production function exponent CGA
 rhocgh(H,CGH)       ces utility exponent
 rholab(A)           CES activity production function exponent labour
 rhoq(C)             Import demand function exponent
 rhosc(A)            CES activity production function exponent  qsc nest
 rhosub(A)           CES activity production function exponent  qsub nest
 rhosubi(A)          CES activity production function exponent subst. intermediates
 rhot(C)             export demand function exponent
 shifin(INSD,A)      share of dom. inst'on i in income of financial asset A
 shifinin(INSD)      share of dom. inst'on i in income of foreign financial asset
 shifl(INSD,FLAB)    share of dom. inst'on i in income of labour flab
 shtr(C)             share of commodity C in trade margins
 supernum(H)         LES supernumerary income
 theta(A,C)          yield of commodity C per unit of activity A
 tins01(INSD)        0-1 par for potential flexing of dir tax rates
 trnsfr(P,P)         transfers fr. inst. to institution ins
 trq(C,PNI)          quantity of trade margins
 trqi(C,A)           quantity of trade margins in investments

*Tax rates
 ta(A)               rate of tax on producer gross output value
 tar(C)              rate of import tariff
 te(C)               rate of tax on exports
 tflbar(FLAB)        rate of direct tax on labour in base (soc sec tax)
 tfinbar             rate of direkt tax on financial return in base
 tinsbar(INSD)       rate of (exog part of) direct tax on dom inst ins
 tq(C,PNI)           quantity tax on commodity c when Pased of purchaser purch
 tqi(C,A)            quantity tax on commodity c when used as investment in activity a
 tv(C,PNI)           value tax on commodity c when purchased of purchaser P
 tvi(C,A)            value tax on commodity c when used as investment in activity a

PARAMETERS
*c. Parameters used for model calibration==================

$ontext
For model calibration, one parameter is created for each model variable
with the suffix "0" added to the variable name. 0 is also added to the
names of parameters whose values are changed in experiments.
$offtext

*Parameters for definition of model parameters
 alphacap0(A)         shift parameter for CES activity production function capital
 alphacga0(A,CGA)     shift parameter for ces activity prod func CGA
 alphacgh0(H,CGH)     shift parameter in CES utility
 alphalab0(A)         shift parameter for CES activity production function labour
 alphasc0(A)          shift parameter for CES activity production function qsc nest
 alphasub0(A)         shift parameter for CES activity production function sub nest
 alphasubi0(A)        shift parameter for CES activity production function subi


 FAP0                 foreign asset position base year
 FLP0                 foreign liabilities base year
 FNAP0                foreign net asset position base year

 gamma0(CGH,H)        per-cap subsist cons of marketed com c for hhd h

 Ppermit0             exogenous price of CO2 permits

 qbarg0(C)            exogenous (unscaled) government demand
 qdst0(C)             stock change
 Qpermit0(A)          domestic supply of CO2 permits per industry

 trnsfr0(P,P)         transfers fr. inst. to institution ins

 ta0(A)               rate of tax on producer gross output value
 tar0(C)              rate of import tariff
 te0(C)               rate of tax on exports
 tins0(INSD)          rate of direct tax on domestic institutions ins
 tq0(C,PNI)           quantity tax on commodity c when purchased of purchaser P
 tqi0(C,A)            quantity tax on commodity c when used as investment in activity a
 tv0(C,PNI)           value tax on commodity c when purchased of purchaser P
 tvi0(C,A)            value tax on commodity c when used as investment in activity a


*Check parameters
  cwtschk             check that CPI weights sum to unity
  shifchk(FLAB)       check that labour payment shares sum to unity
  shifinchk(A)        chack that financial return shares sum to unity

*Parameters for variable initialization
  CPI0                consumer price index (Based on purchaser prices)
  DMPC0               change in marginal propensity to consume for selected inst
  DTINS0              change in domestic institution tax share
  EG0                 total current government expenditure
  EH0(H)              household consumption expenditure
  EXR0                exchange rate
  FSAV0               foreign savings in domestic currency (negative if we invest abroad)
  FTM0(C,PNI)         fix part of trade margins in value
  FTMINV0(C,A)        fix part of trade margins on investments in value
  GADJ0               government demand scaling factor
  GOVSHR0             govt consumption share of absorption
  GRPROF0(A,FCAP)     gross profit in activity a
  GRRENT0(A,FLAND)    gross rents in activity a
  GSAV0               government savings
  IADJ0(A,FCAP)       investment scaling factor (for fixed capital formation)
  IADJM0              general investment scaling factor
  INVSHR0             investment share of absorption
  MPC0(INSD)          marginal propensity to consume for dom non-gov inst ins
  MPCADJ0             savings rate scaling factor
  Netpermit0          net between demestic supply and domestic use of CO2 permits
  PA0(A)              output price of activity a
  PCAP0(A)            price of capital aggregate
  PCGA0(A,CGA)        price of intermediate aggregate CGA in activity a
  PCGH0(H,CGH)        price of aggregated commodity CGH in household H
  PDS0(C)             supply price for com'y c produced & sold domestically
  PE0(C)              price of exports
  PI0(A,FCAP)         price of investments in activity a
  PLAB0(A)            price of labour aggregate
  PLEO0(A)            price of intermediate aggregate
  PM0(C)              price of imports
  PQ0(C)              price of composite good c
  PSC0(A)             part of price covering aggregate qsc (production less leontief inputs)
  PSUB0(A)            part of price covering aggregate substitutables
  PSUBI0(A)           part of price covering aggregate substitutable intermediates
  PWE0(C)             world price of exports
  PWM0(C)             world price of imports
  PX0(C)              average output price
  QA0(A)              level of domestic activity
  QAGGINV0(A,FCAP)    quantity of investmetns in activity a and capital fcap
  QCAP0(A)            quantity of capital aggregate
  QCGA0(A,CGA)        qunatity of aggregated intermediate CGA
  QCGH0(H,CGH)        quantity of aggregated commodity CGH in household H
  QD0(C)              quantity of domestic sales
  QE0(C)              quantity of exports
  QF0(F,A)            quantity demanded of factor f from activity a
  QFS0(F)             quantity of factor supply
  QG0(C)              quantity of government consumption
  QH0(H,C,CGH)        quantity consumed of commodity c by hhd h in nest cgh
  QINT0(C,A)          quantity of intermediate demand for c from activity a
  QINTA0(CSUBI,A,CGA) quantity of intermediate demand for c from act a in CGA
  QINV0(C,A,FCAP)     quantity of fixed investment demand
  QLAB0(A)            quantity of labour aggregate
  QLEO0(A)            quantity of aggregate intermediate leontief input
  QM0(C)              quantity of imports
  QQ0(C)              quantity of composite goods supply
  QSC0(A)             quantity of aggregate production less leontief inputs
  QSUB0(A)            quantity of aggregate substitutables part of production
  QSUBI0(A)           quantity of aggregate substitutable intermediates
  QT0(C)              quantity of trade margin demand for commodity c
  QX0(C)              quantity of aggregate marketed commodity output
  TABS0               total absorption
  TFIN0               rate of direct tax on financial return
  TFINADJ0            capital tax scaling factor
  TFLAB0(FLAB)        rate of direct tax on labour (soc sec tax)
  TINS0(INSD)         rate of direct tax on domestic institutions ins
  TINSADJ0            direct tax scaling factor
  TLABADJ0            labour tax scaling factor
  TM0(C,PNI)          trade margins
  TMI0(C,A)           trade margins on investments
  WALRAS0             savings-investment imbalance (should be zero)
  WEALTH0(H)          the wealth of household h
  WF0(F)              economy-wide wage (rent) for factor f
  WFDIST0(f,A)        factor wage distortion variable
  YFIN0(A)            total income from domestic financial assets A
  YFLAB0(FLAB)        LABOUR income from domestic and foreign activities
  YG0                 total current government income
  YH0(H)              income of (domestic non-governmental) institution ins
  YIFL0(INSD,FLAB)    income of institution ins from factor f
  YIFIN0(INSD)        income of institution ins from financial assets
  ;



*4. OPTIONS ###############################################################
*In this section most off the options for the SAINTBASE.GMS are specified #
*##########################################################################

*CHOICE OF INDATA ==========================================

*INCLUDE ONE COUNTRY DATA SET

*DATA REQUIREMENTS
$ontext
The indatafile would include a SAM where trademargins, value-taxes and
quantity-taxes are in totals. These three rows would be specified on products
in three tables named: tmmat(C,P), tqmat(C,P) and tvmat(C,P)

Note that the use table in the sam SAM(C,AC) should be in basic prices for all
accounts except of the exports in 'ROW' where it should be with export taxes
included (or in most cases with export subsidies subtracted) but without trade
margins. Trademargins on export should as for other purchasers be specified in tmmat.
================================================================================
$offtext

*Remove asterisk in front of ONE (AND ONLY ONE) of the following lines
*or add a new line for a new file with country data



*Indata of the optimal solution in the closed economy,
*used to produce base solutions for tables 3.2 and 4.1.
*$INCLUDE INDATACOM_OPT.INC

*indata used for table 3.2
*$INCLUDE INDATACOM_SINGEL_LEO.INC

*indata used for table 4.1 low elasticity of substitution
*$INCLUDE INDATACOM_SINGEL_LOW.INC

*indata used for table 4.1 high elasticity of substitution
*$INCLUDE INDATACOM_SINGEL_HIGH.INC

*Indata of the optimal solution in the open economy,
*used to produce base solutions for table 5.2.
*$INCLUDE INDATACOM_OPEN_OPT.INC

*indata used for table 5.2 low trade elasticities
*$INCLUDE INDATACOM_OPEN_SINGEL_LOW.INC

*indata used for table 5.2 high trade elasticities
$INCLUDE INDATACOM_OPEN_SINGEL_HIGH.INC


*=SCALING OF INDATA=============================================================
*For scaling all indata remove asterix and choose an appropriate number. All
*data would be divided with this number.

 scaling = 1;

*=END OF SCALING OF INDATA======================================================




*CHOICE OF FUNCTIONAL FORMS ==========================================
*In the includefile below the elasticities and the nest structures of the
*model is defined.
*It is easy to experiment with different include files
*However be carefull so that they are consistent with the indata
*file chosen above. They must have the same set of commodities.

*Remove asterisk in front of ONE (AND ONLY ONE) of the following lines

*Functional forms for the closed economy with leontief technology
*$INCLUDE elascomleo.inc

*Functional forms for the closed economy with low elasticity of substitution
*$INCLUDE ELASCOM.INC

*Functional forms for the closed economy with high elasticity of substitution
*$INCLUDE ELASCOM_2.INC

*Functional forms for the open economy with low trade elasticities
*$INCLUDE elascomopen_low.inc

*Functional forms for the open economy with high trade elasticities
$INCLUDE elascomopen.inc








*CHOICE OF SOLVER TO BE USED IN SAINTBASE.GMS===================================
*If solverchice is equal to 1 the model would be solved using MCP
*If solverchoice is equal to 2 the model would be solved using NLP
*If both of the following lines have an asterix in the beginning the modell
*would not be solved at all. So the asterisk should be removed from one and
*only one of the following lines

 SOLVERCHOICE   = 1;
* SOLVERCHOICE   = 2;

*Note for chosing what nlp or mcp solver to choice you have to adjust the settings
*on your own computer.  In GAMSIDE you use the OPTION command in the file meny.
*Choose solver and investigate the MCP and NLP columns for your prefered choice.
*===============================================================================


*Calibration method for investments=============================================

*Setting tobinqpar equal to 1 adjusts depreciation rates so that tobin q is equal to one

*Setting tobinqpar equal to 2 gives the same adjustment but it also adjusts FSAV
*so that FSAV equals depreciations on foreign owned capital. This is necesary
*if you want to create a base scenario in dynamic simulations where nothing happens.
*Such base scenario would make it easier to evaluate the dynamic effects from the simulations.

*If this calibration method is used it is recomended that you investigate the parameter
*deprate(A,FCAP) to se whether these vaues could be considered as realistic depreciation rates.
*For tobinqpar = 2 it is also recomended to chech FSAVADJ to se the size of these adjustments.

*tobinqpar = 2    ;
*===============================================================================

*OPTIONAL PROCEDURE DEALING WITH FIX TRADE MARGINS (TWO PRICE TARIFFS)==========
*The disaggregation of trade margins give an opportunity to calibrate realistic
*averge prices for different purchaser.
*However there are reasons to beleive that marginal prices do not differ between
*purchasers as much as average prices, due to two price tarifs and similar
*arrangements. Using this procedure you can devide the trade margin into a
*marginal and a fix part. Indata is the parameter margprice(C,P) that has
*to be defined below.
*By removing the asterix in front of the following line the procedure is activated.
 FIXTMPAR        = 1;
*If the procedure is not activated all trade margins are treated as marginal.
*(The model does not support fix trade margins on exports so on exports all trade
*margins are treated as marginal regardless of what is specified here.)

*The parameter below will defines the maximum amount of marginal trade margins
*as share of basic price under the use of the fixtrade margins procedure. The
*rest of the disaggregated trade margins will be treated as a fix purchase of
*the trade commodity.

 margprice(C,PNI) = 0.3;

*===============================================================================



*OPTIONAL PROCEDURE DEALING WITH REEXPORT=======================================
*In this CGE model no reexports are allowed. If exports exceeds domestic
*production this procedure will subtract an equal amount from both import
*and export so that export would be equal to domestic production.
*By removing the asterix in front of the following line the procedure is activated.

 ANETTRADE        = 1;


*===============================================================================





*5. DATABASE ##########################################################

*Scaling of Indata:=============================================================
 SAM(AC,ACP)  = SAM(AC,ACP)/scaling;
 TQMAT(C,P)   = TQMAT(C,P)/scaling;
 TVMAT(C,P)   = TVMAT(C,P)/scaling;
 TMMAT(C,P)   = TMMAT(C,P)/scaling;
 binvmat(C,A) = binvmat(C,A)/scaling;
 TQINV(C,A)   = TQINV(C,A)/scaling;
 TVINV(C,A)   = TVINV(C,A)/scaling;
 TMINV(C,A)   = TMINV(C,A)/scaling;
 FNAP0        = FNAP0/scaling  ;
 Qpermit0(A)  = Qpermit0(A)/scaling   ;
 Netpermit0   = Netpermit0/scaling    ;


 QFBASE(F,A)  =  QFBASE(F,A) / scaling;

*SAM ADJUSTMENTS ===============================================================
*In this section, some minor adjustments are made in the SAM (when
*needed) to fit the model structure.

*Eliminating payments of any account to itself.
 SAM(ACNT,ACNT) = 0;

*OPTIONAL INCNETTRADE PROCEDURE=================================================
Parameter
EXPKORR(C)  corrections made in import and export
DOMEXP(C)   domestic production divided by exports (should never be less than one)
;
DOMEXP(C)=0;
EXPKORR(C)=0;

if(ANETTRADE        = 1,
$INCLUDE   NETTRADE.INC
);
*END OF OPTIONAL INCNETTRADE PROCEDURE==========================================


*OPTIONAL FIX TRADE MARGINS PROCEDURE===========================================
parameter
tempfixtm;
if(FIXTMPAR        = 1,
$INCLUDE   FIXTM.INC
else
margtm(C,PNI) = tmmat(C,PNI) ;
margtminv(C,A) = tminv(C,A) ;
);

*END OF OPTIONAL FIX TRADE MARGINS PROCEDURE====================================


*END OF SAM ADJUSTMENTS=========================================================



*Checking SAM balance=================================================
*Do NOT make any changes in the parameter SAM after this line!!!!!!!!!

*Account totals are recomputed. Check for SAM balance.
 SAM('TOTAL',ACNT) = SUM(ACNTP, SAM(ACNTP,ACNT));
 SAM(ACNT,'TOTAL') = SUM(ACNTP, SAM(ACNT,ACNTP));

 SAMBALCHK(AC)   = SAM('TOTAL',AC) - SAM(AC,'TOTAL');


*Additional set definitions based on country SAM======================

*CD is the set for commodities with domestic sales of domestic output
*i.e., for which (value of sales at producer prices)
*              > (value of exports at producer prices)
 CD(C)  = YES$
    (SUM(A, SAM(A,C)) GT (SAM(C,'ROW') - SAM('EXPTAX',C)) );

 CDN(C) = NOT CD(C);

 CE(C)  = YES$(SAM(C,'ROW'));
 CEN(C) = NOT CE(C);

 CM(C)  = YES$(SAM('ROW',C));
 CMN(C) = NOT CM(C);

 CX(C) = YES$SUM(A, SAM(A,C));

 CTR(C)
 $( SAM(C,'TMT'))
  = YES;


 PNE(PNI)= YES; PNE('ROW') = NO;

 CLEO(C) = YES; CLEO(CSUBI) = NO;
 ANETS(A) = YES; ANETS(AETS) = NO;


 FOSSILNPERM(FOSSIL) = YES; FOSSILNPERM(FOSSILPERM) = NO ;


 CGOV(C)$SAM(C,'GOV') = YES;

*Fine-tuning non-SAM data============================================


*Eliminating superfluous elasticity data=========

 TRADELAS(C,'SIGMAT')$(CEN(C) OR (CE(C) AND CDN(C))) = 0;
 TRADELAS(C,'SIGMAQ')$(CMN(C) OR (CM(C) AND CDN(C))) = 0;
 TRADELAS(C,'SIGMACET')$(CEN(C) OR (CE(C) AND CDN(C))) = 0;
 TRADELAS(C,'SIGMAARM')$(CMN(C) OR (CM(C) AND CDN(C))) = 0;

 PRODELAS(A,PRDELAS)$(NOT SAM('TOTAL',A))     = 0;


 LESELAS1(CGH,H)$(NOT SUM(C, usehcdef(C,CGH)*SAM(C,H)))         = 0;



*Diagnostics=====================================

*Include file that displays and generates information that may be
*useful when debugging data set.
$INCLUDE DIAGNOSTICS.INC



*6. CALIBRATION ########################################################
*the following parameter defines what commodities that are
*included in a specific capital good
capdef(C,'CAP')$SUM(A, binvmat(C,A))  =1     ;
*recalculation of deprates if tobinQ should be equal to one.====================
parameter
 invshare           parameter to calibrate depreciation rates
 GNIBASE1           temporary calculated GNI from SAM data
 qagginvsam(A,FCAP) temporary calculation of aggregated investments
 tvishare(C,A)      the share of tvi that not falls on fix trade margins
 FSAVADJ            parameter to adjust foreign savings
 ;

*financial return to other countries as share of return on domestic assets
*Note that this calibration method assumes the same share for all assets
 finout(A)=SAM('ROW','STOCK')/SUM(AP, SUM(FCAP,  SAM(FCAP,AP))
               +SUM(FLANDP,  SAM(FLANDP,AP))+Qpermit0(AP)* Ppermit0);

 tvishare(C,A)$(BINVMAT(C,A)+TQINV(C,A)+tminv(C,A)) =
   (BINVMAT(C,A)+TQINV(C,A)+margtminv(C,A)) / (BINVMAT(C,A)+TQINV(C,A)+tminv(C,A)) ;

 qagginvsam(A,FCAP) = SUM(C, capdef(C,FCAP) *
 (binvmat(C,A) + tqinv(C,A) + tvinv(C,A)*tvishare(C,A) + margtminv(C,A)))  ;

if (tobinqpar = 2,
FSAVADJ = SAM('S-I','ROW') - SUM(A, finout(A)*SUM(FCAP, qagginvsam(A,FCAP)));
SAM('S-I','ROW') = SAM('S-I','ROW') - FSAVADJ;
SAM('GOV','ROW') = SAM('GOV','ROW') + FSAVADJ;
SAM('S-I','GOV') = SAM('S-I','GOV') + FSAVADJ;
 );

 GNIBASE1 = SUM((C,H), SAM(C,H))+ SUM(H, SAM('TMT',H)+ SAM('TQT',H)+SAM('TVT',H))+
            SUM(C, SAM(C,'S-I'))+ SAM('TMT','S-I')+ SAM('TQT','S-I')+SAM('TVT','S-I')+
            SUM(C, SAM(C,'GOV'))+ SAM('TMT','GOV')+ SAM('TQT','GOV')+SAM('TVT','GOV')+
            SUM(C, SAM(C,'DSTK')+ SAM(C,'ROW')) + SAM('TMT','ROW')- SUM(C, SAM('ROW',C))+
            SUM(FLAB, SAM(FLAB,'ROW')) + SAM('STOCK','ROW') + SUM(H, SAM(H,'ROW'))-
            SUM(FLAB, SAM('ROW',FLAB)) - SAM('ROW','STOCK') - SUM(H, SAM('ROW',H))+
            SAM('GOV','ROW')- SAM('ROW','GOV') ;

 invshare(A,FCAP)$SUM(C, capdef(C,FCAP)) = SAM(FCAP,A) / SUM(C, capdef(C,FCAP) *
             (binvmat(C,A) + tqinv(C,A) + tvinv(C,A)*tvishare(C,A) + margtminv(C,A)));

 Display invshare;

 RETURN = returnbal*EXP(-1*FNAP0/GNIBASE1)  ;

* If Tobin Q is equal to one investments should be equal to depreciation.
* The following if statement calculates deprates that makes investments optimal.
* It assumes that PI is set to 1.
* Moreover it overwrites eventually specified physical quantities on capital so
* that these will be recalculated below.

if (tobinqpar = 1 or tobinqpar = 2,
 deprate(A,FCAP)= RETURN/(invshare(A,FCAP)-1);
 QFSBASE(FCAP)= 0   ;
 QFBASE(FCAP,A)= 0  ;
 );
*End off recalculation of deprates if tobinQ should be equal to one.============

display deprate;

*Physical factor quantities======================

PARAMETERS
 WFA(F,A)          wage for factor f in activity a (used for calibration)
 WFAT(FCAP,A)      wage for factor f in activity a if Tobin Q =1(used for calibration)
 QF2BASE(F,A)      qnty of fac f employed by act a (extracted data)

 ;

*If there is a SAM payment from A to FLAB and supply (but not
*demand) quantities have been defined in the country data file,
*then the supply values are used to compute demand quantities.
 QF2BASE(FLAB,A)$(SAM(FLAB,A)$((NOT QFBASE(FLAB,A))$QFSBASE(FLAB)))
   = QFSBASE(FLAB)*SAM(FLAB,A)/SUM(AP, SAM(FLAB,AP));

*If there is a SAM payment from A to FLAB and neither supply nor
*demand quantities have been defined in the country data file,
*then SAM values are used as quantities
 QF2BASE(FLAB,A)$(SAM(FLAB,A)$((QFBASE(FLAB,A) EQ 0)$(QFSBASE(FLAB) EQ 0)))
                                                    = SAM(FLAB,A);

*If there is a SAM payment from A to FLAB and demand quantities have
*been defined in the country data file, then this information is used.
 QF2BASE(FLAB,A)$QFBASE(FLAB,A) = QFBASE(FLAB,A);

*If there is a SAM payment from A to FLAND and supply (but not
*demand) quantities have been defined in the country data file,
*then the supply values are used to compute demand quantities.
 QF2BASE(FLAND,A)$(SAM(FLAND,A)$((NOT QFBASE(FLAND,A))$QFSBASE(FLAND)))
   = QFSBASE(FLAND)*SAM(FLAND,A)/SUM(AP, SAM(FLAND,AP));

*If there is a SAM payment from A to FLAND and neither supply nor
*demand quantities have been defined in the country data file,
*then SAM values are used as quantities
 QF2BASE(FLAND,A)$(SAM(FLAND,A)$((QFBASE(FLAND,A) EQ 0)$(QFSBASE(FLAND) EQ 0)))
                                                    = SAM(FLAND,A);

*If there is a SAM payment from A to FLAND and demand quantities have
*been defined in the country data file, then this information is used.
 QF2BASE(FLAND,A)$QFBASE(FLAND,A) = QFBASE(FLAND,A);


*Required return for investments in domestic activities
 PI0(A,FCAP)$SUM(C, BINVMAT(C,A) * capdef(C,FCAP)) = 1;
 WFAT(FCAP,A)=(deprate(A,FCAP)+RETURN)*PI0(A,FCAP) ;

*If there is a SAM payment from A to FCAP and supply (but not
*demand) quantities have been defined in the country data file,
*then the supply values are used to compute demand quantities.
 QF2BASE(FCAP,A)$(SAM(FCAP,A)$((NOT QFBASE(FCAP,A))$QFSBASE(FCAP)))
   = QFSBASE(FCAP)*SAM(FCAP,A)/SUM(AP, SAM(FCAP,AP));

*If there is a SAM payment from A to FCAP and neither supply nor
*demand quantities have been defined in the country data file,
*quantities are adjusted in order to get Tobin Q equal to 1
 QF2BASE(FCAP,A)$(SAM(FCAP,A)$((QFBASE(FCAP,A) EQ 0)$(QFSBASE(FCAP) EQ 0)))
                                                    = SAM(FCAP,A)/ WFAT(FCAP,A);

*If there is a SAM payment from A to FCAP and demand quantities have
*been defined in the country data file, then this information is used.
 QF2BASE(FCAP,A)$QFBASE(FCAP,A) = QFBASE(FCAP,A);




*Defining factor employment and supply.
 QF0(F,A)  = QF2BASE(F,A);
 QFS0(F)   = SUM(A, QF0(F,A));

*Activity-specific wage is activity labor payment over employment
 WFA(F,A)$SAM(F,A) = SAM(F,A)/QF0(F,A);


*Economy-wide wage average is total factor income over employment
 WF0(F) = SUM(A, SAM(F,A))/SUM(A, QF0(F,A));

DISPLAY
"If the value of WF0 for any factor is very different from one (< 0.1"
"or >10) the user may consider rescaling the initial values for QFBASE"
"or QFSBASE for this factor to get a value of WF0 such that"
"0.1 < WF0 < 10"
 WF0
 QF0
 ;

*Wage distortion factor
 wfdist0(f,A)$SAM(F,A) = WFA(F,A)/WF0(F);



*Price block=====================================

$ontext

The prices PDS, PX, and PE  may be initialized at any desired price.
The user may prefer to initialize these prices at unity or, if
he/she is interested in tracking commodity flows in physical units, at
commodity-specific, observed prices (per physical unit). For any given
commodity, these three prices should be identical. Initialization at
observed prices may be attractive for commodities with quantity taxation.
If so, the corresponding quantity values reflect physical
units (given the initial price) and realistic taxrates could be used in the model.
Initilising of supply prices is done in the indata file using the parameter PSUP(C)

The non-commodity prices, EXR and PA may be initizalized at any desired level.
In practice, it may be preferable to initialize EXR and PA at unity.

If physical units are used, the user should select the unit (tons vs.
'000 tons) so that initial price and quantity variables are reasonably
scaled (for example between 1.0E-2 and 1.0E+3) -- bad scaling may cause
solver problems. Initialization at unity should cause no problem as long
as the initial SAM is reasonably scaled.

$offtext






 PE0(C)$CE(C)        = PSUP(C);
 PX0(C)$CX(C)        = PSUP(C);
 PDS0(C)$CD(C)       = PSUP(C);
 PM0(C) = PDS0(C)  ;

 PA0(A)       = 1;

 EXR0          = 1 ;

*OUTPUT, IMPORT AND EXPORT CALIBRATION==========================================

*Output quantity = value received by producers divided by producer price


 QX0(C)$SUM(A, SAM(A,C))
         =  SUM(A, SAM(A,C)) / PX0(C);

*Export quantity = export revenue received by producers
*(ie. minus tax and trade margins) divided by export price.


 QE0(C)$SAM(C,'ROW')    =  (SAM(C,'ROW') - SAM('EXPTAX',C))/PE0(C);

*RoW export price = RoW export payment  / export qnty
*(ie. the amount paid per unit by the purchaser divided by the exchange rate
 PWE0(C)$QE0(C) = ((SAM(C,'ROW')+ margtm(C,'ROW'))/EXR0) / QE0(C);



*Export tax = RoW export payment  / value of export with trade margins included
 te0(C)$SAM(C,'ROW') = SAM('EXPTAX',C)/(SAM(C,'ROW')+margtm(C,'ROW'));
 te(C)               =  te0(C);

*Quantity of output sold domestically = output quantity less quantity
*exported = value of domestic sales divided by domestic supply price

 QD0(C)$CD(C) =  QX0(C) - QE0(C);

*Define import price to equal domestic price so that import and domestic
*units are the same to the purchaser. If no domestic good, set PM to 1.


 tar0(C)$SAM('ROW',C)
               = SAM('IMPTAX',C) / SAM('ROW',C);
 tar(C)         = tar0(C);

 PM0(C)$(QD0(C) EQ 0) = 1 ;

*Import quantity = demander payment for imports (including tariffs)
*divided by demander price.
 QM0(C)$CM(C) = (SAM('ROW',C) + SAM('IMPTAX',C))/PM0(C);
*World price = import value (in foreign currency / import quantity
 PWM0(C)$QM0(C)= (SAM('ROW',C)/EXR0) / QM0(C);



*Composite supply is the sum of domestic market sales and imports
*(since they are initialized at the same price).
 QQ0(C)$(CD(C) OR CM(C)) = QD0(C) + QM0(C) ;
 PQ0(C)$QQ0(C) = (SAM(C,'TOTAL') - SAM(C,'ROW'))/QQ0(C);





*DEMAND AND CPI CALIBRATION=====================================================


*calculate quantities by dividing SAM values with the prices:
 QINT0(C,A)$PQ0(C) = SAM(C,A)/PQ0(C);
 QH0(H,C,CGH)$PQ0(C) = usehcdef(C,CGH)*SAM(C,H)/PQ0(C);
 QG0(C)$PQ0(C) = SAM(C,'GOV')/PQ0(C);
 QINV0(C,A,FCAP)$PQ0(C) = capdef(C,FCAP)*BINVMAT(C,A)/PQ0(C);

*calculate substitutable intermediate per aggregate
 QINTA0(CSUBI,A,CGA) = QINT0(CSUBI,A)*proddefcsubi(CSUBI,CGA);

*calculate trade margins per unit by dividing margtm with quantities:
 TM0(C,A)$QINT0(C,A) = margtm(C,A) / QINT0(C,A)  ;
 TM0(C,H)$SAM(C,H) = margtm(C,H) / SUM(CGH, QH0(H,C,CGH))  ;
 TM0(C,'GOV')$QG0(C) = margtm(C,'GOV') / QG0(C)  ;
 TMI0(C,A)$SUM(FCAP, QINV0(C,A,FCAP)) = margtminv(C,A) / SUM(FCAP, QINV0(C,A,FCAP))  ;
 TM0(C,'ROW')$QE0(C) = margtm(C,'ROW') / QE0(C)  ;
 FTM0(C,PNI) = fixtm(C,PNI) ;
 FTMINV0(C,A) = fixtminv(C,A) ;

*calculate quantity tax rates by dividing taxpayments with quantities:
 tq0(C,A)$QINT0(C,A) = TQMAT(C,A) / QINT0(C,A)  ;
 tq0(FOSSILPERM,AETS)$QINT0(FOSSILPERM,AETS) = tq0(FOSSILPERM,AETS)
                     - carbshare(FOSSILPERM) * Ppermit0;
 tq(C,A)=tq0(C,A) ;
 tq(FOSSILPERM,AETS) = tq0(FOSSILPERM,AETS) + carbshare(FOSSILPERM) * Ppermit0;



 tq0(C,H)$SAM(C,H) = TQMAT(C,H) / SUM(CGH, QH0(H,C,CGH))  ;
 tq(C,H)=tq0(C,H) ;
 tq0(C,'GOV')$QG0(C) = TQMAT(C,'GOV') / QG0(C)  ;
 tq(C,'GOV')=tq0(C,'GOV');
 tqi0(C,A)$SUM(FCAP, QINV0(C,A,FCAP)) = TQINV(C,A) / SUM(FCAP, QINV0(C,A,FCAP))  ;
 tqi(C,A)=tqi0(C,A);

*calculate value tax rates by dividing taxpayments with purchaser price
*less value tax. (Note that fis trade margins is also included here since the
*matrix of total trade margins are used):
 tv0(C,A)$QINT0(C,A) = TVMAT(C,A) / (QINT0(C,A)*PQ0(C)+TQMAT(C,A)+tmmat(C,A))  ;
 tv(C,A)=tv0(C,A);
 tv0(C,H)$SAM(C,H) = TVMAT(C,H) / (SUM(CGH, QH0(H,C,CGH))*PQ0(C)+TQMAT(C,H)+tmmat(C,H))  ;
 tv(C,H)=tv0(C,H);
 tv0(C,'GOV')$QG0(C) = TVMAT(C,'GOV') / (QG0(C)*PQ0(C)+TQMAT(C,'GOV')+tmmat(C,'GOV'))  ;
 tv(C,'GOV')=tv0(C,'GOV');
 tvi0(C,A)$SUM(FCAP, QINV0(C,A,FCAP)) = TVINV(C,A) / (BINVMAT(C,A)+TQINV(C,A)+tminv(C,A));
 tvi(C,A)=tvi0(C,A);



*calculate the share of commodity CTR in trade margins:
 shtr(CTR)= SAM(CTR,'TMT') / SUM(CTRP, SAM(CTR,'TMT'));

*calculate the quantity of trade margins per unit by dividing the value with
*the price
 trq(C,PNI)$SUM(CTR, shtr(CTR)*PQ0(CTR) )
                                 = TM0(C,PNI) / SUM(CTR, shtr(CTR)*PQ0(CTR)) ;
 trqi(C,A)$SUM(CTR, shtr(CTR)*PQ0(CTR) )
                                 = TMI0(C,A) / SUM(CTR, shtr(CTR)*PQ0(CTR)) ;
 ftmq(C,PNI)$SUM(CTR, shtr(CTR)*PQ0(CTR) )
                                 = FTM0(C,PNI) / SUM(CTR, shtr(CTR)*PQ0(CTR)) ;
 ftmqinv(C,A)$SUM(CTR, shtr(CTR)*PQ0(CTR) )
                                 = FTMINV0(C,A) / SUM(CTR, shtr(CTR)*PQ0(CTR)) ;

*calculate the quantity of each commodity included in trade margins
 QT0(CTR)=  shtr(CTR)*(SUM(A, SUM(C, trq(C,A)*QINT0(C,A)))
                  +SUM((C,PNI), ftmq(C,PNI))+SUM((C,A), ftmqinv(C,A))
                  +SUM(H, SUM(C, trq(C,H)*SUM(CGH, QH0(H,C,CGH))))
                  +SUM(A, SUM(C, trqi(C,A)*SUM(FCAP, QINV0(C,A,FCAP))))
                  +SUM(C, trq(C,'GOV')*QG0(C))+SUM(C, trq(C,'ROW')*QE0(C)));


*CPI weight by comm'y = hhd cons value for comm'y / total cons value

 cwts(C,H)     = (SAM(C,H)+margtm(C,H)+TVMAT(C,H)+TQMAT(C,H)) /
                 SUM((CP,HP), SAM(CP,H)+margtm(CP,H)+TVMAT(CP,H)+TQMAT(CP,H));

 CWTSCHK       = SUM(C, SUM(H, cwts(C,H)));

 CPI0          = SUM(C, SUM(H, cwts(C,H)*(1+tv(C,H))*(PQ0(C)+tq(C,H)+TM0(C,H)))) ;

*normalizing CPI at base year to unity
 cwts(C,H)     = cwts(C,H) / CPI0 ;
 CPI0          = SUM(C, SUM(H, cwts(C,H)*(1+tv(C,H))*(PQ0(C)+tq(C,H)+TM0(C,H)))) ;

*investments calibration
 qbarinv(C,A,FCAP)$BINVMAT(C,A) = capdef(C,FCAP)*BINVMAT(C,A)/PQ0(C);
 QINV0(C,A,FCAP)           = qbarinv(C,A,FCAP);
 IADJ0(A,FCAP)             = 1;




 QAGGINV0(A,FCAP)$SUM(C, QINV0(C,A,FCAP)) =
   SUM(C, (1+tvi(C,A))*(PQ0(C)+tqi(C,A)+TMI0(C,A))*QINV0(C,A,FCAP))/PI0(A,FCAP);

 iwts(C,A,FCAP)$QAGGINV0(A,FCAP) = qbarinv(C,A,FCAP)/ QAGGINV0(A,FCAP);

*Stock changes
 qdst0(C)$PQ0(C) = SAM(C,'DSTK')/PQ0(C);
 qdst(C)         = qdst0(C);

*CALIBRATION OF PRODUCTION FUNCTIONS============================================


*QA is GROSS of tax, so base for ta is
 ta0(A)        = SAM('ACTTAX',A) / (SAM(A,'TOTAL'));
 ta(A)         = ta0(A);




*Activity quantity = payment to activity divided by activity price
*output GROSS of tax
 QA0(A)        =  SAM('TOTAL',A)/PA0(A) ;

*Unit aggregate price = total aggregate / aggregate quantity

 QSC0(A)       =  SAM('TOTAL',A)- SAM('ACTTAX',A)- SUM(C, fixtm(C,A)*(1+tv(C,A)))
                  - SUM(CLEO, (1+tv(CLEO,A))*(SAM(CLEO,A)+margtm(CLEO,A)
                                          +TQMAT(CLEO,A)))  ;



 PSC0(A)       =  (SAM('TOTAL',A)- SAM('ACTTAX',A)- SUM(C, fixtm(C,A)*(1+tv(C,A)))
                  - SUM(CLEO, (1+tv(CLEO,A))*(SAM(CLEO,A)+margtm(CLEO,A)
                              +TQMAT(CLEO,A))))/QSC0(A)  ;

 QSUB0(A)       =  (SUM(FLAB, SAM(FLAB,A)) + SUM(CSUBI, (1+tv(CSUBI,A))
                   *(SAM(CSUBI,A)+ margtm(CSUBI,A)+TQMAT(CSUBI,A))))  ;


 PSUB0(A)       =  (SUM(FLAB, SAM(FLAB,A)) + SUM(CSUBI, (1+tv(CSUBI,A))
                   *(SAM(CSUBI,A)+ margtm(CSUBI,A)+TQMAT(CSUBI,A))))/QSUB0(A)  ;


 QLAB0(A)       =  SUM(FLAB, SAM(FLAB,A))  ;


 PLAB0(A)       =  SUM(FLAB, SAM(FLAB,A))/QLAB0(A)  ;

 QCAP0(A)       =  SUM(FCAP, SAM(FCAP,A)) + SUM(FLAND, SAM(FLAND,A)) ;

 PCAP0(A)       =  (SUM(FCAP, SAM(FCAP,A)) + SUM(FLAND, SAM(FLAND,A)))/QCAP0(A)  ;


 QSUBI0(A)       =  SUM(CSUBI, (1+tv(CSUBI,A))*(SAM(CSUBI,A)+ margtm(CSUBI,A)
                                          +TQMAT(CSUBI,A)))  ;

 PSUBI0(A)$QSUBI0(A)     =  SUM(CSUBI, (1+tv(CSUBI,A))*(SAM(CSUBI,A)
                      + margtm(CSUBI,A) +TQMAT(CSUBI,A)))/QSUBI0(A)  ;

 QCGA0(A,CGA)       =  SUM(CSUBI$proddefcsubi(CSUBI,CGA), (1+tv(CSUBI,A))*(SAM(CSUBI,A)+ margtm(CSUBI,A)
                                          +TQMAT(CSUBI,A)))  ;

 PCGA0(A,CGA)$QCGA0(A,CGA)     =  SUM(CSUBI$proddefcsubi(CSUBI,CGA), (1+tv(CSUBI,A))*(SAM(CSUBI,A)
                      + margtm(CSUBI,A) +TQMAT(CSUBI,A)))/ QCGA0(A,CGA)  ;



* Gross profits in activity a

 GRPROF0(A,FCAP)    =  SAM(FCAP,A)  ;
 GRRENT0(A,FLAND)    =  SAM(FLAND,A)  ;


*Yield coefficient = quantity produced of a specific commodity
*                      /total activity quantity in the industry
 theta(A,C)$SAM(A,C) =  (SAM(A,C)/ PX0(C) ) / QA0(A);

*Aggregate substitutables coefficient = aggregate substitutable quantity
*                                          / output quantity
 isc(A)        =  QSC0(A)/QA0(A) ;


*Quantity of leontieff inputs equals the sum of the quantities of each commodity

 QLEO0(A) = SUM(CLEO(C), SAM(CLEO,A)  / PQ0(CLEO)) ;

*Intermediate leontief input coefficient = input use / output quantity
 inta(A)       = QLEO0(A) / QA0(A) ;

 ica(CLEO,A)$(QLEO0(A))
               = SAM(CLEO,A)/PQ0(CLEO) / QLEO0(A) ;

 pleo0(A) = SUM(CLEO, (PQ0(CLEO)+tq(CLEO,A)
                         +TM0(CLEO,A))*(1+tv(CLEO,A))*ica(CLEO,A)) ;

DISPLAY
 CWTSCHK, CPI0;







*Compute exponents from elasticites
 rhoq(C)$(CM(C) AND CD(C)) = (1/TRADELAS(C,'SIGMAQ')) - 1;
 rhot(C)$(CE(C) AND CD(C))  = (1/TRADELAS(C,'SIGMAT')) + 1;
 rhoarm(C)$(CM(C) AND CD(C)) = (1/TRADELAS(C,'SIGMAARM')) - 1;
 rhocet(C)$(CE(C) AND CD(C))  = (1/TRADELAS(C,'SIGMACET')) + 1;
 rhosc(A)         = (1/PRODELAS(A,'SIGMASC')) - 1;
 rhosub(A)        = (1/PRODELAS(A,'SIGMASUB')) - 1;
 rhosubi(A)       = (1/PRODELAS(A,'SIGMASUBI')) - 1;
 rholab(A)        = (1/PRODELAS(A,'SIGMALAB')) - 1;
 rhocap(A)        = (1/PRODELAS(A,'SIGMACAP')) - 1;
 rhocga(A,CGA)$(SUM(CSUBI, QINTA0(CSUBI,A,CGA))gt 0) = (1/CPRODELAS(A,CGA)) - 1;




*CES activity production function  sub nest
PARAMETER
  predeltasub(A)  dummy used to define deltaa
  ;

 predeltasub(A)  = 0 ;
 predeltasub(A)$(QSUBI0(A))
                = (PLAB0(A)/PSUBI0(A))*(QLAB0(A)/QSUBI0(A))**(1+rhosub(A)) ;
 deltasub(A)$predeltasub(A) = predeltasub(A)/(1 + predeltasub(A)) ;
 alphasub0(A)$deltasub(A)
                = QSUB0(A)/((deltasub(A)*QLAB0(A)**(-rhosub(A))
                  +(1-deltasub(A))*QSUBI0(A)**(-rhosub(A)))**(-1/rhosub(A))) ;

 alphasub(A) = alphasub0(A);

*CES activity production function  qsc nest
PARAMETER
  predeltasc(A)  dummy used to define deltaa
  ;

 predeltasc(A)  = 0 ;
 predeltasc(A)$(QSUB0(A))
                = (PCAP0(A)/PSUB0(A))*(QCAP0(A)/QSUB0(A))**(1+rhosc(A)) ;
 deltasc(A)$predeltasc(A) = predeltasc(A)/(1 + predeltasc(A)) ;
 alphasc0(A)$deltasc(A)
                = QSC0(A)/((deltasc(A)*QCAP0(A)**(-rhosc(A))
                  +(1-deltasc(A))*QSUB0(A)**(-rhosc(A)))**(-1/rhosc(A))) ;

 alphasc(A) = alphasc0(A);

*CES activity production function  capital and land

 deltacap(FCAP,A)$SAM(FCAP,A)
            = (wfdist0(FCAP,A) * WF0(FCAP)
              * (QF0(FCAP,A))**(1+rhocap(A)) )
              / (SUM(FCAPP, wfdist0(FCAPP,A) * WF0(FCAPP)
              *(QF0(FCAPP,A))**(1+rhocap(A)))+SUM(FLANDP, wfdist0(FLANDP,A) * WF0(FLANDP)
              *(QF0(FLANDP,A))**(1+rhocap(A))));

 deltaland(FLAND,A)$SAM(FLAND,A)
            = (wfdist0(FLAND,A) * WF0(FLAND)
              * (QF0(FLAND,A))**(1+rhocap(A)) )
              / (SUM(FCAPP, wfdist0(FCAPP,A) * WF0(FCAPP)
              *(QF0(FCAPP,A))**(1+rhocap(A)))+SUM(FLANDP, wfdist0(FLANDP,A) * WF0(FLANDP)
              *(QF0(FLANDP,A))**(1+rhocap(A))));

 alphacap0(A)= QCAP0(A)/( SUM(FCAP$(QF0(FCAP,A)), deltacap(FCAP,A)*QF0(FCAP,A)
               **(-rhocap(A)))+SUM(FLAND$(QF0(FLAND,A)), deltaland(FLAND,A)*QF0(FLAND,A)
               **(-rhocap(A))) )**(-1/rhocap(A));

 alphacap(A) = alphacap0(A);

*CES activity production function  labour



 deltalab(FLAB,A)$SAM(FLAB,A)
            = (wfdist0(FLAB,A) * WF0(FLAB)
              * (QF0(FLAB,A))**(1+rholab(A)) )
              / SUM(FLABP, wfdist0(FLABP,A) * WF0(FLABP)
              *(QF0(FLABP,A))**(1+rholab(A)));


 alphalab0(A)= QLAB0(A)/( SUM(FLAB$(QF0(FLAB,A)), deltalab(FLAB,A)*QF0(FLAB,A)
               **(-rholab(A))) )**(-1/rholab(A));

 alphalab(A) = alphalab0(A);

*CES activity production function  substitutable intermediates

 deltacga(CSUBI,A,CGA)$QINTA0(CSUBI,A,CGA)
             = (1+tv(CSUBI,A))*(PQ0(CSUBI)+tq(CSUBI,A)+TM0(CSUBI,A))
             * ( QINTA0(CSUBI,A,CGA))**(1+rhocga(A,CGA))
             / SUM(CSUBIP, (1+tv(CSUBIP,A))*(PQ0(CSUBIP)+tq(CSUBIP,A)+TM0(CSUBIP,A))
             *( QINTA0(CSUBIP,A,CGA))**(1+rhocga(A,CGA)));


 alphacga0(A,CGA)$(SUM(CSUBI, QINTA0(CSUBI,A,CGA))gt 0)
             = QCGA0(A,CGA)/( SUM(CSUBI$(QINT0(CSUBI,A)),
               deltacga(CSUBI,A,CGA)*QINTA0(CSUBI,A,CGA)
               **(-rhocga(A,CGA))) )**(-1/rhocga(A,CGA));

 alphacga(A,CGA) = alphacga0(A,CGA);


 deltasubi(A,CGA)$(SUM(CSUBI, SAM(CSUBI,A)*proddefcsubi(CSUBI,CGA)) gt 0)
            = PCGA0(A,CGA) * (QCGA0(A,CGA))**(1+rhosubi(A))
            / SUM(CGAP, PCGA0(A,CGAP)*(QCGA0(A,CGAP))**(1+rhosubi(A)));

 alphasubi0(A)$( sum(csubi, SAM(CSUBI,A))gt 0)
      = QSUBI0(A)/( SUM(CGA$(QCGA0(A,CGA)), deltasubi(A,CGA)*QCGA0(A,CGA)
               **(-rhosubi(A))) )**(-1/rhosubi(A));

 alphasubi(A) = alphasubi0(A);


*Export supply
 deltat(C)$(CE(C) AND CD(C))
   = 1 / (1 + PDS0(C)/PE0(C)*(QE0(C)/QD0(C))**(rhot(C)-1));

*CET transformation
 deltacet(C)$(CE(C) AND CD(C))
   = 1 / (1 + PDS0(C)/PE0(C)*(QE0(C)/QD0(C))**(rhocet(C)-1));

 alphat(C)$(CE(C) AND CD(C))
   = QX0(C) / (deltacet(C)*QE0(C)**rhocet(C) + (1-deltacet(C))
                 *QD0(C)**rhocet(C))**(1/rhocet(C));


*Armington aggregation

PARAMETER
 predelta(C)  dummy used to define deltaq
 predeltaarm(C)  dummy used to define deltaarm
 ;

 predelta(C)$(CM(C) AND CD(C))
   = (PM0(C)/(PDS0(C)))*(QM0(C)/QD0(C))**(1+rhoq(C)) ;

 deltaq(C)$(CM(C) AND CD(C))
   = predelta(C)/(1 + predelta(C)) ;

 predeltaarm(C)$(CM(C) AND CD(C))
   = (PM0(C)/(PDS0(C)))*(QM0(C)/QD0(C))**(1+rhoarm(C)) ;

 deltaarm(C)$(CM(C) AND CD(C))
   = predelta(C)/(1 + predelta(C)) ;

 alphaq(C)$(CM(C) AND CD(C))
               = QQ0(C)/(deltaarm(C)*QM0(C)**(-rhoarm(C))
                 +(1-deltaarm(C))*QD0(C)**(-rhoarm(C)))**(-1/rhoarm(C)) ;




*Institution block===============================

* Calibration of transfers: Transfers from ROW are assumed to be fixed in
* foreign currency and thus will change when the exchange rate are changed,
* while transfers to ROW are assumed to be fixed in domestic currency and thus
* not influenced by changes in exchange rate.

 Ppermit =  Ppermit0 ;
 Qpermit(A) =  Qpermit0(A) ;
 Netpermit0 = Ppermit0 * (SUM((FOSSILPERM,AETS), QINT0(FOSSILPERM,AETS)*
              carbshare(FOSSILPERM)) - SUM(AETS, Qpermit0(AETS)));

*Transfers to RoW from institutions
 trnsfr0('ROW',INSD) = SAM('ROW',INSD);
 trnsfr0('ROW','GOV') = SAM('ROW','GOV') - NETPERMIT0 ;
 trnsfr('ROW',INSD) = trnsfr0('ROW',INSD) ;

*Transfers from RoW to institutions
 trnsfr0(INSD,'ROW') = SAM(INSD,'ROW')/EXR0;
 trnsfr(INSD,'ROW') = trnsfr0(INSD,'ROW');

*Government transfers
 trnsfr0(INSD,'GOV') = SAM(INSD,'GOV')/CPI0;
 trnsfr(INSD,'GOV') = trnsfr0(INSD,'GOV');



Display trnsfr ;

*Institutional income
 YH0(H) = SAM('TOTAL',H);

*labour income by factor category
 YFLAB0(FLAB) = SUM(A, SAM(FLAB,A))+SAM(FLAB,'ROW');

*Institution income from labour
 YIFL0(INSD,FLAB) = SAM(INSD,FLAB);

*Income from financial asset a
 YFIN0(A) = SUM(FCAP,  GRPROF0(A,FCAP))+ SUM(FLAND,  GRRENT0(A,FLAND))
          + Qpermit0(A)* Ppermit0;

*Institution income from financial assets
 YIFIN0(INSD) = SAM(INSD,'STOCK')      ;

*labour income to other countries as share of domestic payment to factor
 labout(FLAB)=SAM('ROW',FLAB)/SUM(A,  WF0(FLAB)*wfdist0(FLAB,A)*QF0(FLAB,A));

*labour income from other countries
 labin(FLAB) = SAM(FLAB,'ROW')/EXR0;



*financial return from other countries
 finin  = SAM('STOCK','ROW')/EXR0;



*Factor taxes are paid only if the receiver of factor income
* is a domestic institution
 tflbar(FLAB)        = SAM('FACTAX',FLAB)/(SAM('TOTAL',FLAB)-SAM('ROW',FLAB));
 tflab0(FLAB)        = tflbar(FLAB);

 tfinbar        = SAM('FACTAX','STOCK')/(SAM('TOTAL','STOCK')-SAM('ROW','STOCK'));
 tfin0        = tfinbar;




Parameter
GNIbase        National income in base year ;


 GNIbase = SUM(A, PA0(A)*QA0(A))
           - SUM(A, ta(A)*PA0(A)*QA0(A)
           + SUM(C, (1+tv(C,A))*(QINT0(C,A)*(PQ0(C)+tq(C,A)+TM0(C,A))+FTM0(C,A))))
           + SUM(A, SUM(C, tq(C,A)*QINT0(C,A)
                 + tv(C,A)*((PQ0(C)+tq(C,A)+TM0(C,A))*QINT0(C,A)+FTM0(C,A))))
          +SUM(H, SUM(C, SUM(CGH, tq(C,H)*QH0(H,C,CGH))
                  +tv(C,H)*((PQ0(C)+tq(C,H)+TM0(C,H))*SUM(CGH, QH0(H,C,CGH))+FTM0(C,H))))
          +SUM(C, tq(C,'GOV')*QG0(C)+tv(C,'GOV')
                  *((PQ0(C)+tq(C,'GOV')+TM0(C,'GOV'))*QG0(C)+FTM0(C,'GOV')))
          +SUM((C,A), tqi(C,A)*SUM(FCAP, QINV0(C,A,FCAP))+tvi(C,A)*((PQ0(C)
                  +tqi(C,A)+TMI0(C,A))*SUM(FCAP, QINV0(C,A,FCAP))+FTMINV0(C,A)))
          + SUM(CM, tar(CM)*QM0(CM)*PWM0(CM))*EXR0
          + SUM(CE, te(CE)*QE0(CE)*PWE0(CE))*EXR0
          + SUM(A, ta(A)*PA0(A)*QA0(A)) + sum(FLAB, labin(FLAB)*EXR0)+ finin*EXR0+
    sum(H,  trnsfr(H,'ROW')*EXR0)+ trnsfr('GOV','ROW')*EXR0 -
    sum(FLAB, labout(FLAB)*SUM(A,  WF0(FLAB)*wfdist0(FLAB,A)*QF0(FLAB,A)) *EXR0)-
    sum(A, finout(A)* ( SUM(FCAP,  WF0(FCAP)*wfdist0(FCAP,A)*QF0(FCAP,A))+
          SUM(FLAND,  WF0(FLAND)*wfdist0(FLAND,A)*QF0(FLAND,A))) *EXR0)-
    sum(H,  trnsfr('ROW',H)) - trnsfr('ROW','GOV') - netpermit0;
*lgga in check av GNI
display GNIbase;
parameters
 GNIDIF1
 GNIDIF2
 GNIERR1
 GNIERR2
 ;

 GNIDIF1  = GNIbase1-GNIbase;

 GNIbase = SUM((C,H), (1+tv(C,H))*((PQ0(C)+tq(C,H)+TM0(C,H))*SUM(CGH, QH0(H,C,CGH))+FTM0(C,H)))
    +SUM((C,A), (1+tvi(C,A))* (PQ0(C)+tqi(C,A)+TMI0(C,A)) * SUM(FCAP, QINV0(C,A,FCAP))+(1+tvi(C,A))*FTMINV0(C,A))
    + SUM(C, PQ0(C)*QDST(C)) + SUM(C, (1+tv(C,'GOV'))*((PQ0(C)+tq(C,'GOV')
    +TM0(C,'GOV'))*QG0(C)+FTM0(C,'GOV'))) + SUM(CE, PWE0(CE)*EXR0*QE0(CE))
    -SUM(CM, PWM0(CM)*EXR0*QM0(CM)) + sum(FLAB, labin(FLAB)*EXR0)
    + finin*EXR0+sum(H,  trnsfr(H,'ROW')*EXR0)+
    trnsfr('GOV','ROW')*EXR0 - sum(FLAB, labout(FLAB)*SUM(A,  WF0(FLAB)*wfdist0(FLAB,A)*QF0(FLAB,A)) *EXR0)-
    sum(A, finout(A)* ( SUM(FCAP,  WF0(FCAP)*wfdist0(FCAP,A)*QF0(FCAP,A))+
          SUM(FLAND,  WF0(FLAND)*wfdist0(FLAND,A)*QF0(FLAND,A))) *EXR0) -
    sum(H,  trnsfr('ROW',H)) - trnsfr('ROW','GOV')- netpermit0;

 GNIDIF2  = GNIbase1-GNIbase;

 display "if the number below is not equal to zero there must be errors in the calibration", GNIDIF1;
 GNIERR1$(GNIDIF1 > 1) = 1/0;

 display "if the number below is not equal to zero there must be errors in the calibration",  GNIDIF2;
 GNIERR2$(GNIDIF2 > 1) = 1/0;


display GNIbase;

*Shares of domestic institutions in labour income (net of factor taxes
*and transfers to RoW).
 shifl(INSD,FLAB)  = SAM(INSD,FLAB)/(SAM(FLAB,'TOTAL') - SAM('FACTAX',FLAB)
                 - SAM('ROW',FLAB));

 SHIFCHK(FLAB)    = SUM(INSD, shifL(INSD,FLAB));

DISPLAY
 SHIFCHK;

*Shares of domestic institutions in financial income (net of factor taxes
*and transfers to RoW).  Note that this calibration method assumes that all
*institutions hold tha market protfolio
 shifin(INSD,A)  = SAM(INSD,'STOCK')/(SAM('STOCK','TOTAL') - SAM('FACTAX','STOCK')
                 - SAM('ROW','STOCK'));

 SHIFINCHK(A)    = SUM(INSD, shifin(INSD,A));

 SHIFININ(INSD) = SAM(INSD,'STOCK')/(SAM('STOCK','TOTAL') - SAM('FACTAX','STOCK')
                 - SAM('ROW','STOCK'));

DISPLAY
 SHIFINCHK;


*foreign liabilities base year  Value of the share of domestic stock held by foreign citisens
 FLP0 = SUM(A, finout(A) *  (SUM(FCAP, GRPROF0(A,FCAP)/(deprate(A,FCAP)+RETURN))
      +SUM(FLAND, GRRENT0(A,FLAND)/RETURN)))  ;


*assets in other countries

 FAP0 = FNAP0+FLP0 ;
 FAP = FAP0;


*return on foreign assets
 factinret$finin =  finin /FAP0 ;


*wealth in household h equals the value of this households share in domestic
*capital plus the value of this households share in foreign assets

 WEALTH0(H) = SUM(A, shifin(H,A)*(1-finout(A))*
      (SUM(FCAP, GRPROF0(A,FCAP)/(deprate(A,FCAP)+RETURN))
      +SUM(FLAND, GRRENT0(A,FLAND)/RETURN)))+ shifinin(H)*FAP0 ;



*Scaling factors for savings and taxrates
 MPCADJ0      = 0;
 TINSADJ0     = 0;
 TLABADJ0     = 0;
 TFINADJ0     = 0;


*Direct tax rates
 TINS0(H)   = SAM('INSTAX',H) / SAM('TOTAL',H);
 tinsbar(H) = TINS0(H);

*"Point" change in savings and direct tax shares
 DMPC0  = 0;
 DTINS0 = 0;


*Selecting institutions for potential "point" change in savings and tax rates

*If DMPC or MPCADJ is flexible, institutions with a value of 1 for mpc01
*change their savings rates.
 mpc01(H)  = 1;

*If DTIMS is flexible, institutions with a value of 1 for tins01 change
*their savings rates.
 tins01(H) = 1;

*Household consumption spending (fix trade margins included)
 EH0(H)        = SUM(C, (SAM(C,H)+ tmmat(C,H)+ TQMAT(C,H))*(1+tv(C,H))) ;


*Government indicators
 YG0           = SAM('TOTAL','GOV');
 EG0           = SAM('TOTAL','GOV') - SAM('S-I','GOV');


 qbarg0(C)     = QG0(C);
 qbarg(C)      = qbarg0(C);
 GADJ0         = 1;
 IADJM0        = 1;
 GSAV0         = SAM('S-I','GOV');




*Houshold consumption=LES calibration===========================================
$ontext
In the Les calibration section fix trade margins are deduced from consumer spending
meaning that the Frisch parameter will determine the ratio of consumer spending less
fix trade margins to supernumary spending.

$offtext
*PCGH initialized at uity

 QCGH0(H,CGH)= SUM(C, QH0(H,C,CGH)*(1+tv(C,H))*(PQ0(C)+tq0(C,H)+TM0(C,H)) );
 PCGH0(H,CGH)$QCGH0(H,CGH)  = SUM(C, QH0(H,C,CGH)*(1+tv(C,H))*(PQ0(C)+tq0(C,H)+TM0(C,H)) )
                     /QCGH0(H,CGH);

PARAMETERS
 BUDSHR(CGH,H)    budget share for marketed commodity c and household h
 BUDSHRCHK(H)    check that budget shares sum to unity
 ELASCHK(H)      check that expenditure elasticities satisfy Engel aggr
 EHTEMP1(H)      houshold spending less fix trade margins
 EHTEMP2(H)      houshold spending less fix trade margins alternative 2
 EHTEMP3(H)      houshold spending less fix trade margins alternative 3
 EHTCHK(H)       check of consistency in houshold spending les FTM
 ;

 EHTEMP1(H) = EH0(H)-SUM(C,(1+tv(C,H))*FTM0(C,H));

 EHTEMP2(H) = SUM(CP, (SAM(CP,H)+TQMAT(CP,H)+margtm(CP,H))*(1+tv(CP,H)));

 EHTEMP3(H) = SUM(CGH, QCGH0(H,CGH)*PCGH0(H,CGH));

display " if these numbers are not equal there must be some error in calibration"
  ehtemp1, ehtemp2, ehtemp3;


 EHTCHK(H)$(ABS(EHTEMP1(H) - EHTEMP2(H)) GT 0.00000001) = 1/0;
 EHTCHK(H)$(ABS(EHTEMP1(H) - EHTEMP3(H)) GT 0.00000001) = 1/0;
 BUDSHR(CGH,H)    = QCGH0(H,CGH)*PCGH0(H,CGH) /   EHTEMP1(H) ;



 BUDSHRCHK(H)   = SUM(CGH, BUDSHR(CGH,H)) ;

 ELASCHK(H)     = SUM(CGH, BUDSHR(CGH,H)*LESELAS1(CGH,H));

DISPLAY BUDSHR,  BUDSHRCHK, LESELAS1,  ELASCHK;

 LESELAS1(CGH,H)   = LESELAS1(CGH,H)/ELASCHK(H);


 ELASCHK(H)      = SUM(CGH, BUDSHR(CGH,H)*LESELAS1(CGH,H))    ;


DISPLAY ELASCHK, LESELAS1;

 beta(CGH,H)   = BUDSHR(CGH,H)*LESELAS1(CGH,H);


 gamma0(CGH,H)$BUDSHR(CGH,H)
     =   (EHTEMP1(H) * ( BUDSHR(CGH,H) + beta(CGH,H)/FRISCH(H)))/
                 PCGH0(H,CGH);

 gamma(CGH,H)   =  gamma0(CGH,H);


*Checking LES parameters===================================
PARAMETERS
* SUBSIST(H)  subsistence spending
 FRISCH2(H)  alt. defn of Frisch -- ratio of cons to supernumerary cons
 LESCHK(H)   check on LES parameter definitions (error mssg if error)

 LESELASP(H,CGH,CGHP) price elasticity bt cgh and cghp for h
*LESELASP defines cross-price elasticities when cgh is different from cghp and
*own-price elasticities when cgh and cghp refer to the same commodity group.
*Source: Dervis, de Melo and Robinson. 1982. General Equilibrium Models
*for Development Policy. Cambridge University Press, p. 483
 ;



 SUPERNUM(H)  = SUM(CGH, gamma(CGH,H)*PCGH0(H,CGH)) ;
 FRISCH2(H)   = -(EH0(H)-SUM(C,(1+tv(C,H))*FTM0(C,H)))/((EH0(H)-SUM(C,(1+tv(C,H))*FTM0(C,H))) - SUPERNUM(H));

Display Frisch, frisch2;

 LESCHK(H)$(ABS(FRISCH(H) - FRISCH2(H)) GT 0.00000001) = 1/0;


*Cross-price elasticities

 LESELASP(H,CGH,CGHP)
    $((ORD(CGH) NE ORD(CGHP)) AND LESELAS1(CGH,H) AND LESELAS1(CGHP,H))
  = -LESELAS1(CGH,H) * PCGH0(H,CGH)*gamma(CGH,H) / EHTEMP1(H) ;



*Own-price elasticities

 LESELASP(H,CGH,CGH)
   = -LESELAS1(CGH,H) * (PCGH0(H,CGH)*gamma(CGH,H) / EHTEMP1(H)  - 1/FRISCH(H));


OPTION LESELASP:3;

DISPLAY

 LESELASP, leselas1
 ;

*Houshold consumption=CES calibration===========================================

*Compute exponents from elasticites
 rhocgh(H,CGH)$(beta(CGH,H)) = (1/CGHELAS(H,CGH)) - 1;


*calibration of the deltha parameter
 deltacgh(H,C,CGH)$(usehcdef(C,CGH)*SAM(C,H))
             = (1+tv(C,H))*(PQ0(C)+tq(C,H)+TM0(C,H))
               * ( QH0(H,C,CGH))**(1+rhocgh(H,CGH))
               / SUM(CP, (1+tv(CP,H))*(PQ0(CP)+tq(CP,H)+TM0(CP,H))
                *( QH0(H,CP,CGH))**(1+rhocgh(H,CGH)));



  alphacgh0(H,CGH)$( sum(c, deltacgh(H,C,CGH))gt 0)
      =  QCGH0(H,CGH)/( SUM(C, deltacgh(H,C,CGH)*QH0(H,C,CGH)
               **(-rhocgh(H,CGH))) )**(-1/rhocgh(H,CGH));

 alphacgh(H,CGH) = alphacgh0(H,CGH);









*marginal propensity to consume  equals total spending less intercept divided
*by total disposable income.
 MPC0(H)  = (EH0(H)- cint(H)*WEALTH0(H))/(SAM('TOTAL',H) - SAM('INSTAX',H)-SAM('ROW',H));
 mpcbar(H) = MPC0(H);







*System-constraint block =========================





 FSAV0         = SAM('S-I','ROW') ;

 TABS0    = SUM((C,H), (1+tv(C,H))*(PQ0(C)+tq(C,H)+TM0(C,H))*SUM(CGH, QH0(H,C,CGH)))
       + SUM(C, (1+tv(C,'GOV'))*(PQ0(C)+tq(C,'GOV')+TM0(C,'GOV'))*QG0(C))
       + SUM((C,A), (1+tvi(C,A))*(PQ0(C)+tqi(C,A)+TMI0(C,A))*SUM(FCAP, QINV0(C,A,FCAP)))
       + SUM(C, PQ0(C)*qdst(C));

 INVSHR0       = SAM('TOTAL','S-I')/TABS0;
 GOVSHR0       = (SUM(C, SAM(C,'GOV'))+SAM('TMT','GOV')+SAM('TQT','GOV')+
                  SAM('TVT','GOV'))/TABS0;

 WALRAS0       = 0;




*7. VARIABLE DECLARATIONS ###########################################
*This section only includes variables that appear in the model.
*The variables are declared in alphabetical order.

VARIABLES
  CPI             consumer price index (based on purchaser prices)
  DMPC            change in marginal propensity to consume for selected inst
  DTINS           change in domestic institution tax share
  EG              total current government expenditure
  EH(H)           household consumption expenditure
  EXR             exchange rate
  FSAV            foreign savings in domestic currency
  FTM(C,PNI)      fix part of trade margins on commodity c purchased of P
  FTMINV(C,A)     fix part of trade margins on investments
  GADJ            government demand scaling factor
  GOVSHR          govt consumption share of absorption
  GRPROF(A,FCAP)  gross profits in activity a
  GRRENT(A,FLAND)  gross rents in activity a
  GSAV            government savings
  IADJ(A,FCAP)    investment scaling factor (for fixed capital formation)
  IADJM           general investment scaling factor
  INVSHR          investment share of absorption
  MPC(INSD)       marginal propensity to consume for dom non-gov inst insd
  MPCADJ          savings rate scaling factor
  Netpermit       net between demestic supply and domestic use of CO2 permits
  PA(A)           output price of activity a
  PCAP(A)         price of capital aggregate
  PCGA(A,CGA)     price of intermediate aggregate CGA in activity a
  PCGH(H,CGH)     price of aggregated commodity CGH in houlhold H
  PDS(C)          supply price for com'y c produced & sold domestically
  PE(C)           price of exports in national currency
  PI(A,FCAP)      price per unit of investments
  PLAB(A)         price of labour aggregate
  PLEO(A)         price of intermediate aggregate
  PM(C)           price of imports in national currency
  PQ(C)           price of composite good c
  PSC(A)          part of price covering aggregate qsc (production less leontief inputs)
  PSUB(A)         part of price covering aggregate substitutables
  PSUBI(A)        part of price covering aggregate substitutable intermediates
  PWE(C)          world price of exports
  PWM(C)          world price of imports
  PX(C)           average output price
  QA(A)           level of domestic activity
  QAGGINV(A,FCAP) quantity of aggregate investments in activity a
  QCAP(A)         quantity price of capital aggregate
  QCGA(A,CGA)     quantity of intermediate commodity group CGA
  QCGH(H,CGH)     quantity of aggregated commodity CGH in houlhold H
  QD(C)           quantity of domestic sales
  QE(C)           quantity of exports
  QF(F,A)         quantity demanded of factor f from activity a
  QFS(F)          quantity of factor supply
  QG(C)           quantity of government consumption
  QH(H,C,CGH)     quantity consumed of commodity c by household h in nest CGH
  QINT(C,A)       quantity of intermediate demand for c from activity a
  QINTA(CSUBI,A,CGA)     quantity of intermediate demand for c from activity a
  QINV(C,A,FCAP)  quantity of fixed investment demand
  QLAB(A)         quantity of labour aggregate
  QLEO(A)         quantity of aggregate leontief intermediate input
  QM(C)           quantity of imports
  QQ(C)           quantity of composite goods supply
  QSC(A)          quantity of production less leontief inputs
  QSUB(A)         quantity of aggregate substitutables part of production
  QSUBI(A)        quantity of aggregate substitutable intermediates
  QT(C)           quantity of trade margin demand for commodity c
  QX(C)           quantity of aggregate marketed commodity output
  TABS            total absorption
  TFIN            rate of direct tax on financial return
  TFINADJ         scaling factor for tax on return from financial assets
  TFLAB(FLAB)     rate of direct tax on labour (soc sec tax)
  TINS(INSD)      rate of direct tax on domestic institutions ins
  TINSADJ         direct tax scaling factor
  TLABADJ         labour tax scaling factor
  TM(C,PNI)       trade margins on commodity C when purchased of P
  TMI(C,A)        trade margins on commodity C when purchased of P and used as investment
  WALRAS          savings-investment imbalance (should be zero)
  WALRASSQR       Walras squared
  WEALTH(H)       the wealth of household H
  WF(F)           economy-wide wage (rent) for factor f
  WFDIST(F,A)     factor wage distortion variable
  YFIN(A)         total income from domestic financial assets A
  YFLAB(FLAB)     labour income from domestic and foreign activities
  YG              current government income
  YH(H)           household income
  YIFL(INSD,FLAB) income of institution ins from factor f
  YIFIN(INSD)     financial income of institution insd
  ;

 Positive variables

  EH
  PA
  PCAP
  PCGA
  PCGH
  PE
  PI
  PLAB
  PLEO
  PM
  PQ
  PSC
  PSUB
  PSUBI
  PX
  QA
  QAGGINV
  QCAP
  QCGA
  QCGH
  QG
  QH
  QINT
  QINTA
  QINV
  QLAB
  QLEO
  QSC
  QSUB
  QSUBI
  QT
  QX
  QQ
  TFLAB
  TINS
  WEALTH
  YFLAB
  YFIN
  YH
  YIFL
  YIFIN
  ;

*8. VARIABLE DEFINITIONS ############################################

*The initial levels of all model variables are defined in this file.

$INCLUDE VARINIT.INC







*9. EQUATION DECLARATIONS ###########################################

EQUATIONS

*Price block===============================================
 PMDEF(C)        domestic import price
 PEDEF(C)        domestic export price
 PQDEF(C)        value of sales in domestic market
 PXDEF(C)        value of marketed domestic output
 PADEF(A)        output price for activity a
 PLEODEF(A)      price of aggregate leontief intermediate input
 PASDEF(A)       output price for activity a defined from supply side
 PSCDEF(A)       output price less leontieff aggregate
 PSUBDEF(A)      substitutables part of price
 CPIDEF          consumer price index


*Production block=========================================
 LEOAGGINT(A)    Leontief aggreg intermed dem (if Leontief top nest)
 LEOAGGSUB(A)    Leontief aggreg value-added dem (if Leontief top nest)
 CESQSCPRD(A)    CES production function qsc nest
 CESSUBPRD(A)    CES production function sub nest
 CESSUBIPRD(A)   CES production function intermediate aggregates
 CESCGAPRD(A,CGA) CES production function substitutable intermediates

 CESCAPPRD(A)    CES production function capital
 CESLABPRD(A)    CES production function labour aggregates
 CESQSCFOC(A)    CES prodfunction first-order condition qsc nest
 CESLABFOC(FLAB,A)   CES prodfunc first-order condition labour aggregates

 CESLANDFOC(FLAND,A) CES value-added first-order condition LAND
 CESCAPFOC(FCAP,A)  CES value-added first-order condition capital
 CESSUBFOC(A)    CES prodfunction first-order condition sub nest
 CESSUBPRD2(A)   instead of sub nest when no substitutable intermediates
 CESSUBIFOC(A,CGA)   CES prodfunction first-order condition  intermediate aggregates
 CESCGAFOC(CSUBI,A,CGA)   CES prodfunction first-order condition  intermediates
 QINTAGG(CSUBI,A)          Aggregation of substitutables over aggregates
 INTDEM(C,A)     intermediate demand for commodity c from activity a
 DOMPROD(C)      Domestic production of commodity c
*Investement block=========================================
 GRPROFDEF(A,FCAP)      Gross profit in activity a
 GRRENTDEF(A,FLAND)     Gross rents in activity a
 INVDEM(C,A,FCAP)       fixed investment demand of c in a
 PIDEF(A,FCAP)         price of one unit of investments
 QAGGINVDEF(A,FCAP)     quantity of aggregate investments in activity a


*Trade block ==============================================
 CET(C)           CET function
 CET2(C)          domestic sales and exports for outputs without both
 ESUPPLY(C)       export supply
 ARMINGTON(C)     composite commodity aggregation function
 COSTMIN(C)       first-order condition for composite commodity cost min
 ARMINGTON2(C)    comp supply for com's without both dom. sales and imports

*Trade margins block ======================================
 QTDEM(C)         demand for trade margins (retailsector) services
 TMEQ(C,PNI)      marginal part of trade margins
 TMIEQ(C,A)       marginal part of trade margins on investments
 FTMDEF(C,PNI)    fixed part of trade margins
 FTMINVDEF(C,A)   fixed part of trade margins on investments
*Institution block ========================================
 YFLABDEF(F)      labour incomes
 YFINDEF(A)       incomes from financial assets
 YIFLDEF(INSD,FLAB)   labour incomes to domestic institutions
 YIFINDEF(INSD)   incomes from financial assets to domestic institutions
 YHDEF(H)         total incomes of domest non-gov't institutions
 WEALTHDEF(H)     the wealth of household H
 EHDEF(H)         household consumption expenditures
 HADEM(H,CGH)     The LES equation (demand for CGH)
 CESCGH(H,CGH)    CES aggregation in houshold utility
 HMDEM(H,C,CGH)   CES cons demand by hhd h for marketed commodity c used in CGH
 PERMITEQ         determine netimport of CO2 permits
 GOVDEM(C)        government consumption demand
 EGDEF            total government expenditures
 YGDEF            total government income

*System constraint block===================================
 COMEQUILTR(C)    composite commodity market equilibrium trade margins commodities
 COMEQUILNTR(C)   composite commodity market equilibrium
 FACEQUIL(F)      factor market equilibrium
 CURACCBAL        current account balance (of RoW)
 GOVBAL           government balance
 TINSDEF(INSD)    direct tax rate for inst ins
 TFLABDEF(FLAB)   labour tax rate
 TFINDEF          tax rate on return  from financial assets
 MPCDEF(INSD)     marg prop to save for inst ins
 SAVINVBAL        savings-investment balance
 OBJEQ            Objective function
 TABSEQ           equation for total absorbtion
 INVABEQ          investment share in absorption
 GDABEQ           government consumption share in absorption

;


*10. EQUATION DEFINITIONS ############################################
*Notational convention inside equations:
*Parameters and "invariably" fixed variables are in lower case.
*"Variable" variables are in upper case.

*Price block===============================================

 PMDEF(C)$CM(C)..     PM(C) =E= pwm(C)*(1 + tar(C))*EXR ;

 PEDEF(C)$CE(C)..     PE(C) =E= pwe(C)*(1 - te(C))*EXR - TM(C,'ROW');

 PQDEF(C)$(CD(C) OR CM(C))..    PQ(C)*QQ(C) =E= PDS(C)*QD(C) + PM(C)*QM(C);

 PXDEF(C)$CX(C)..  PX(C)*QX(C) =E= PDS(C)*QD(C) + PE(C)*QE(C);

 PADEF(A)..  PA(A) =E= SUM(C, PX(C)*theta(A,C));

 PLEODEF(A).. PLEO(A) =E= SUM(CLEO, (PQ(CLEO)+tq(CLEO,A)
                         +TM(CLEO,A))*(1+tv(CLEO,A))*ica(CLEO,A)) ;

 PASDEF(A)..  PA(A)*(1-ta(A))*QA(A)-SUM(C, FTM(C,A)*(1+tv(C,A)))
                      =E= PSC(A)*QSC(A) + PLEO(A)*QLEO(A) ;

 PSCDEF(A)..    PSC(A)*QSC(A) =E= PCAP(A)*QCAP(A) + PSUB(A)*QSUB(A)  ;

 PSUBDEF(A)..   PSUB(A)*QSUB(A) =E= PLAB(A)*QLAB(A) + PSUBI(A)*QSUBI(A)  ;

 CPIDEF..  CPI =E= SUM(C, SUM(H, (1+tv(C,H))*(PQ(C)+tq(C,H)+TM(C,H))*cwts(C,H)));




*Production block======================================================


 LEOAGGINT(A)..  QLEO(A) =E= inta(A)*QA(A) ;

 LEOAGGSUB(A)..  QSC(A) =E= isc(A)*QA(A) ;

 CESQSCPRD(A)..
   QSC(A) =E= alphasc(A)*(deltasc(A)*QCAP(A)**(-rhosc(A))+
        (1-deltasc(A))*QSUB(A)**(-rhosc(A)))**(-1/rhosc(A)) ;

 CESSUBPRD(A)$alphasubi0(A)..
   QSUB(A) =E= alphasub(A)*(deltasub(A)*QLAB(A)**(-rhosub(A))+
        (1-deltasub(A))*QSUBI(A)**(-rhosub(A)))**(-1/rhosub(A)) ;

 CESSUBPRD2(A)$(alphasubi0(A)=0)..
   QSUB(A)  =E= QLAB(A)    ;

 CESCAPPRD(A)..
   QCAP(A) =E= alphacap(A)*(SUM(FCAP, deltacap(FCAP,A)*QF(FCAP,A)**
                               (-rhocap(A)))+SUM(FLAND, deltaland(FLAND,A)*QF(FLAND,A)**
                               (-rhocap(A))))**(-1/rhocap(A)) ;

 CESSUBIPRD(A)$alphasubi0(A)..
   QSUBI(A) =E= alphasubi(A)* (SUM(CGA$(QCGA0(A,CGA)*deltasubi(A,CGA) gt 0),
                               deltasubi(A,CGA)*QCGA(A,CGA)**
                               (-rhosubi(A))))**(-1/rhosubi(A)) ;

 CESLABPRD(A)..
   QLAB(A) =E= alphalab(A)* (SUM(FLAB$(deltalab(FLAB,A)*QF0(FLAB,A) gt 0),
                               deltalab(FLAB,A)*QF(FLAB,A)**
                               (-rholab(A))))**(-1/rholab(A)) ;


 CESCGAPRD(A,CGA)$alphacga(A,CGA)..
   QCGA(A,CGA) =E= alphacga(A,CGA)*
                   (SUM(CSUBI$deltacga(CSUBI,A,CGA), deltacga(CSUBI,A,CGA)*QINTA(CSUBI,A,CGA)**
                   (-rhocga(A,CGA))))**(-1/rhocga(A,CGA)) ;


 CESQSCFOC(A)..
   QCAP(A) =E= QSUB(A)*((PSUB(A)/PCAP(A))*(deltasc(A)/
                                 (1 - deltasc(A))))**(1/(1+rhosc(A))) ;

 CESSUBFOC(A)$alphasubi0(A)..
   QLAB(A) =E= QSUBI(A)*((PSUBI(A)/PLAB(A))*(deltasub(A)/
                                 (1 - deltasub(A))))**(1/(1+rhosub(A))) ;

 CESCAPFOC(FCAP,A)$deltacap(FCAP,A)..
   WF(FCAP)*wfdist(FCAP,A) =E=
   PCAP(A) * QCAP(A) * (SUM(FCAPP, deltacap(FCAPP,A)*QF(FCAPP,A)**(-rhocap(A)))
   + SUM(FLAND, deltaland(FLAND,A)*QF(FLAND,A)**(-rhocap(A))))**(-1)
   *deltacap(FCAP,A)*QF(FCAP,A)**(-rhocap(A)-1);

 CESLANDFOC(FLAND,A)$deltaland(FLAND,A)..
   WF(FLAND)*wfdist(FLAND,A) =E=
   PCAP(A) * QCAP(A) * (SUM(FCAPP, deltacap(FCAPP,A)*QF(FCAPP,A)**(-rhocap(A)))
   + SUM(FLANDP, deltaland(FLANDP,A)*QF(FLANDP,A)**(-rhocap(A))))**(-1)
   *deltaland(FLAND,A)*QF(FLAND,A)**(-rhocap(A)-1);

  CESLABFOC(FLAB,A)$deltalab(FLAB,A)..
   WF(FLAB)*wfdist(FLAB,A) =E=
   PLAB(A) * QLAB(A) * SUM(FLABP, deltalab(FLABP,A)*QF(FLABP,A)**(-rholab(A)))**(-1)
   *deltalab(FLAB,A)*QF(FLAB,A)**(-rholab(A)-1);

  CESSUBIFOC(A,CGA)$deltasubi(A,CGA)..
   PCGA(A,CGA) =E=
   PSUBI(A) * QSUBI(A) * SUM(CGAP, deltasubi(A,CGAP)*QCGA(A,CGAP)**(-rhosubi(A)))**(-1)
   *deltasubi(A,CGA)*QCGA(A,CGA)**(-rhosubi(A)-1);

  CESCGAFOC(CSUBI,A,CGA)$deltacga(CSUBI,A,CGA)..
   (1+tv(CSUBI,A))*(PQ(CSUBI)+tq(CSUBI,A)+TM(CSUBI,A)) =E=
   PCGA(A,CGA) * QCGA(A,CGA) * SUM(CSUBIP, deltacga(CSUBIP,A,CGA)
   *QINTA(CSUBIP,A,CGA)**(-rhocga(A,CGA)))**(-1)
   *deltacga(CSUBI,A,CGA)*QINTA(CSUBI,A,CGA)**(-rhocga(A,CGA)-1);

  QINTAGG(CSUBI,A)..
   QINT(CSUBI,A) =E= SUM(CGA, QINTA(CSUBI,A,CGA));

 INTDEM(CLEO,A)$ica(CLEO,A).. QINT(CLEO,A) =E= ica(CLEO,A)*QLEO(A);


 DOMPROD(C)..
    QX(C) =E= SUM(A, theta(A,C)*QA(A)) ;


*Investments block====================================================

 GRPROFDEF(A,FCAP)..  GRPROF(A,FCAP)=E=  WF(FCAP) * wfdist(FCAP,A)* QF(FCAP,A);

 GRRENTDEF(A,FLAND)..  GRRENT(A,FLAND)=E=  WF(FLAND) * wfdist(FLAND,A)* QF(FLAND,A);

 INVDEM(C,A,FCAP)$qbarinv(C,A,FCAP)..  QINV(C,A,FCAP) =E= IADJM * IADJ(A,FCAP)*qbarinv(C,A,FCAP);

 PIDEF(A,FCAP)$SUM(C,qbarinv(C,A,FCAP))..       PI(A,FCAP) =E= SUM(C,  (1+tvi(C,A))*
                                       (PQ(C)+tqi(C,A)+TMI(C,A))*iwts(C,A,FCAP));

 QAGGINVDEF(A,FCAP)$SUM(C,qbarinv(C,A,FCAP))..      QAGGINV(A,FCAP) =E=
               SUM(C,  (1+tvi(C,A))*(PQ(C)+tqi(C,A)+TMI(C,A))*QINV(C,A,FCAP))/PI(A,FCAP);

*Trade Block===========================================================

 CET(C)$(CE(C) AND CD(C))..
    QX(C) =E= alphat(C)*(deltacet(C)*QE(C)**rhocet(C) +
                         (1 - deltacet(C))*QD(C)**rhocet(C))**(1/rhocet(C)) ;

  ESUPPLY(C)$(CE(C) AND CD(C))..
   QE(C) =E=  QD(C)*((PE(C)/PDS(C))*
                ((1 - deltat(C))/deltat(C)))**(1/(rhot(C)-1)) ;

 CET2(C)$( (CD(C) AND CEN(C)) OR (CE(C) AND CDN(C)) )..
   QX(C) =E= QD(C) + QE(C);


 ARMINGTON(C)$(CM(C) AND CD(C))..
   QQ(C) =E= alphaq(C)*(deltaarm(C)*QM(C)**(-rhoarm(C)) +
                      (1 -deltaarm(C))*QD(C)**(-rhoarm(C)))**(-1/rhoarm(C)) ;

 COSTMIN(C)$(CM(C) AND CD(C))..
   QM(C) =E= QD(C)*((PDS(C)/PM(C))*(deltaq(C)/(1 - deltaq(C))))
                                                   **(1/(1 + rhoq(C)));

 ARMINGTON2(C)$( (CD(C) AND CMN(C)) OR (CM(C) AND CDN(C)) )..
   QQ(C) =E= QD(C) + QM(C);

*Trade margins block==========================================

 QTDEM(CTR)..
  QT(CTR) =E= shtr(CTR)*(SUM(A, SUM(C, trq(C,A)*QINT(C,A)))
                  +SUM(H, SUM(C, trq(C,H)*SUM(CGH, QH(H,C,CGH))))
                  +SUM((C,A), trqi(C,A)*SUM(FCAP, QINV(C,A,FCAP)))
                  +SUM(C, trq(C,'GOV')*QG(C))+SUM(C, trq(C,'ROW')*QE(C))
                  +SUM(PNI, SUM(C, ftmq(C,PNI)))
                  +SUM(A, SUM(C, ftmqinv(C,A))));

 TMEQ(C,PNI)$trq(C,PNI)..     TM(C,PNI) =e= SUM(CTR, trq(C,PNI)*shtr(CTR)*PQ(CTR));

 TMIEQ(C,A)$trqi(C,A)..     TMI(C,A) =e= SUM(CTR, trqi(C,A)*shtr(CTR)*PQ(CTR));

 FTMDEF(C,PNI)$ftmq(C,PNI)..     FTM(C,PNI) =e= SUM(CTR, ftmq(C,PNI)*shtr(CTR)*PQ(CTR));

 FTMINVDEF(C,A)$ftmqinv(C,A)..     FTMINV(C,A) =e= SUM(CTR, ftmqinv(C,A)*shtr(CTR)*PQ(CTR));
*Institution block ========================================

  YFLABDEF(FLAB)..  YFLAB(FLAB) =E= SUM(A, WF(FLAB)*wfdist(FLAB,A)*QF(FLAB,A))+labin(FLAB)*EXR;

  YFINDEF(A)..  YFIN(A) =E= SUM(FCAP,  GRPROF(A,FCAP))
             +SUM(FLAND,  GRRENT(A,FLAND))+Qpermit(A)* Ppermit;

  YIFLDEF(INSD,FLAB)$shifl(INSD,FLAB)..
               YIFL(INSD,FLAB) =E= shifl(INSD,FLAB)*(1-tflab(FLAB))*(YFLAB(FLAB) -
               labout(FLAB)*SUM(A,  WF(FLAB)*wfdist(FLAB,A)*QF(FLAB,A)));

  YIFINDEF(INSD)$SUM(A, shifin(INSD,A))..
               YIFIN(INSD) =E= SUM(A, shifin(INSD,A)*(1-tfin)*
               (1 - finout(A))* YFIN(A))+shifinin(INSD)*(1-tfin)*finin*EXR;

  YHDEF(H)..
  YH(H) =E=   SUM(FLAB, YIFL(H,FLAB)) +  YIFIN(H)
                   + trnsfr(H,'GOV')*CPI + trnsfr(H,'ROW')*EXR;


  WEALTHDEF(H)..   WEALTH(H) =E= SUM(A, shifin(H,A)*(1-finout(A))*
      (SUM(FCAP, GRPROF(A,FCAP)/(deprate(A,FCAP)+RETURN))
      +SUM(FLAND, GRRENT(A,FLAND)/RETURN)))+ shifinin(H)*FAP ;

 EHDEF(H)..
  EH(H) =E= MPC(H) * ((1 - TINS(H)) * YH(H)- trnsfr('ROW',H)) + cint(H) * WEALTH(H);

 HADEM(H,CGH)$QCGH0(H,CGH)..    QCGH(H,CGH) * PCGH(H,CGH) =E= PCGH(H,CGH)*gamma(CGH,H)
                     + beta(CGH,H)*(EH(H) - SUM(CP, FTM(CP,H)*(1+tv(CP,H)))
                     -SUM(CGHP, PCGH(H,CGHP)*gamma(CGHP,H)));

 CESCGH(H,CGH)$rhocgh(H,CGH)..
                           QCGH(H,CGH) =E= alphacgh(H,CGH)*(SUM(C,
                           deltacgh(H,C,CGH)*QH(H,C,CGH)**
                           (-rhocgh(H,CGH))))**(-1/rhocgh(H,CGH));

 HMDEM(H,C,CGH)$deltacgh(H,C,CGH)..
                      (1+tv(C,H))*(PQ(C)+tq(C,H)+TM(C,H)) =E=
                         QCGH(H,CGH) * PCGH(H,CGH)*SUM(CP, deltacgh(H,CP,CGH)*
                         QH(H,CP,CGH)**(-rhocgh(H,CGH)))**(-1)
                         *deltacgh(H,C,CGH)*QH(H,C,CGH)**(-rhocgh(H,CGH)-1);

 PERMITEQ..  NETPERMIT =E= Ppermit *
          (SUM((FOSSILPERM,AETS), QINT(FOSSILPERM,AETS)*
          carbshare(FOSSILPERM)) - SUM(AETS, Qpermit(AETS))) ;

 GOVDEM(C)$CGOV(C)..  QG(C) =E= GADJ*qbarg(C);

 YGDEF..
   YG =E= SUM(H, TINS(H)*YH(H))
          + SUM(FLAB, tflab(FLAB)*(YFLAB(FLAB) - labout(FLAB)
           *SUM(A,  WF(FLAB)*wfdist(FLAB,A)*QF(FLAB,A))))
          +   tfin  *(SUM(A, (1 - finout( A))*YFIN( A))+finin *EXR)
          + SUM(C, tar(C)*pwm(C)*QM(C))*EXR
          + SUM(C, te(C)*pwe(C)*QE(C))*EXR
          + SUM(FLAB, YIFL('GOV',FLAB)) +  YIFIN('GOV')
          + trnsfr('GOV','ROW')*EXR
          + SUM((A,C),  tq(C,A)*QINT(C,A)
                 +tv(C,A)*(PQ(C)+tq(C,A)+TM(C,A))*QINT(C,A))
          + SUM(A, ta(A)*PA(A)*QA(A))
          + SUM((H,C,CGH),  tq(C,H)* QH(H,C,CGH)
                 +tv(C,H)*(PQ(C)+tq(C,H)+TM(C,H))* QH(H,C,CGH))
          + SUM((C,A), tqi(C,A)*SUM(FCAP, QINV(C,A,FCAP))
                 +tvi(C,A)*(PQ(C)+tqi(C,A)+TMI(C,A))*SUM(FCAP, QINV(C,A,FCAP)))
          + SUM(C, tq(C,'GOV')*QG(C)
                 +tv(C,'GOV')*(PQ(C)+tq(C,'GOV')+TM(C,'GOV'))*QG(C))
          + SUM((PNI,C),  tv(C,PNI)*FTM(C,PNI))
          + SUM((A,C),  tvi(C,A)*FTMINV(C,A))      ;

 EGDEF..
   EG =E= SUM(C, (1+tv(C,'GOV'))*(PQ(C)+tq(C,'GOV')+TM(C,'GOV'))*QG(C))
          + SUM(H, trnsfr(H,'GOV'))*CPI + trnsfr('ROW','GOV') + NETPERMIT
          +SUM(C, FTM(C,'GOV')*(1+tv(C,'GOV'))) + SUM(AETS, Qpermit(AETS))*Ppermit ;


*System constraint block===================================

 FACEQUIL(F)..  SUM(A, QF(F,A)) =E= QFS(F);

 COMEQUILTR(CTR)..
   QQ(CTR) =E= SUM(A, QINT(CTR,A)) + SUM(H, SUM(CGH, QH(H,CTR,CGH))) + QG(CTR)
                + SUM((A,FCAP), QINV(CTR,A,FCAP))  + qdst(CTR) + QT(CTR);

 COMEQUILNTR(C)$(not CTR(C))..
   QQ(C) =E= SUM(A, QINT(C,A)) + SUM(H, SUM(CGH, QH(H,C,CGH))) + QG(C)
                + SUM((A,FCAP), QINV(C,A,FCAP)) + qdst(C);

 CURACCBAL$(SUM(AC, ABS(SAM('ROW',AC)+ABS(SAM(AC,'ROW')))))..
          SUM(C, pwm(C)*QM(C))*EXR
          + SUM(FLAB, labout(FLAB)*SUM(A,  WF(FLAB)*wfdist(FLAB,A)*QF(FLAB,A)))
          + SUM(A, finout(A)* YFIN(A))
          + SUM(INSD, trnsfr('ROW',INSD)) + NETPERMIT =E=
          SUM(C, pwe(C)*QE(C))*EXR + sum(FLAB, labin(FLAB)*EXR)+ finin*EXR
          + SUM(INSD, trnsfr(INSD,'ROW'))*EXR + FSAV;



 GOVBAL.. YG =E= EG + GSAV;

 TINSDEF(H)..
  TINS(H) =E= tinsbar(H)*(1 + TINSADJ*tins01(H))
                   + DTINS*tins01(H);

 TFLABDEF(FLAB)..
  TFLAB(FLAB) =E= tflbar(FLAB)*(1 + TLABADJ);

 TFINDEF..
  TFIN =E= tfinbar*(1 + TFINADJ);

 MPCDEF(H)..
  MPC(H)  =E= mpcbar(H)*(1 + MPCADJ*mpc01(H))
                   + DMPC*mpc01(H);

 SAVINVBAL..
   SUM(H, (1-MPC(H)) * ((1 - TINS(H)) * YH(H)- trnsfr('ROW',H)) - cint(H) * WEALTH(H))
    + GSAV + FSAV =E=
   SUM((C,A), (PQ(C) + tqi(C,A) + TMI(C,A))*(1+tvi(C,A))*SUM(FCAP, QINV(C,A,FCAP)))
    + SUM(C, PQ(C)*qdst(C))+SUM((C,A), FTMINV(C,A)*(1+tvi(C,A)))+ WALRAS ;

 OBJEQ..   WALRASSQR   =E= WALRAS*WALRAS ;

 TABSEQ..
  TABS =E=  SUM((C,H), (1+tv(C,H))*(PQ(C)+tq(C,H)+TM(C,H))*SUM(CGH, QH(H,C,CGH)))
         + SUM(C, (1+tv(C,'GOV'))*(PQ(C)+tq(C,'GOV')+TM(C,'GOV'))*QG(C))
         + SUM((C,A,FCAP), (1+tvi(C,A))*(PQ(C)+tqi(C,A)+TMI(C,A))*QINV(C,A,FCAP))
         + SUM(C, PQ(C)*qdst(C));



 INVABEQ.. INVSHR*TABS =E= SUM((C,A,FCAP), (1+tvi(C,A))* (PQ(C)+tqi(C,A)+TMI(C,A))
         *QINV(C,A,FCAP))+SUM((C,A), FTMINV(C,A)*(1+tvi(C,A))) + SUM(C, PQ(C)*qdst(C));

 GDABEQ..  GOVSHR*TABS =E= SUM(C, (1+tv(C,'GOV'))*
         (PQ(C)+tq(C,'GOV')+TM(C,'GOV'))*QG(C))+SUM(C, (1+tv(C,'GOV'))*FTM(C,'GOV'));

*11. MODEL DEFINITION ###############################################


MODEL MCPCGE
 /



*Price block===============================================
 PMDEF.PM
 PEDEF.PE
 PQDEF.PQ
 PXDEF.PX
 PADEF.PA
 PLEODEF.PLEO
 PASDEF.PSC
 PSCDEF.PSUB
 PSUBDEF.PLAB
 CPIDEF


*Production block=========================================
 LEOAGGINT.QLEO
 LEOAGGSUB.QA
 CESQSCPRD.QSC
 CESSUBPRD.QSUB
 CESSUBPRD2.QSUB
 CESCAPPRD.QCAP
 CESSUBIPRD.QSUBI
 CESLABPRD.QLAB
 CESCGAPRD.QCGA
 CESQSCFOC.PCAP
 CESSUBFOC.PSUBI
 CESCAPFOC
 CESLANDFOC
 CESLABFOC

 CESSUBIFOC.PCGA
 CESCGAFOC.QINTA
 QINTAGG.QINT
 INTDEM.QINT
 DOMPROD.QX


*Investement block=========================================

 GRPROFDEF.GRPROF
 GRRENTDEF.GRRENT
 INVDEM.QINV
 PIDEF.PI
 QAGGINVDEF.QAGGINV



*Trade block ==============================================
 CET
 CET2
 ESUPPLY
 ARMINGTON
 COSTMIN
 ARMINGTON2

*Trade margins block ======================================
 QTDEM.QT
 TMEQ.TM
 TMIEQ.TMI
 FTMDEF.FTM
 FTMINVDEF.FTMINV
*Institution block ========================================

 YFLABDEF.YFLAB
 YFINDEF.YFIN
 YIFLDEF.YIFL
 YIFINDEF.YIFIN
 YHDEF.YH
 WEALTHDEF.WEALTH
 EHDEF.EH
 HADEM.PCGH
 CESCGH.QCGH
 HMDEM.QH
 GOVDEM.QG
 PERMITEQ.NETPERMIT
 EGDEF
 YGDEF

*System constraint block===================================
 COMEQUILTR.QQ
 COMEQUILNTR.QQ
 FACEQUIL
 CURACCBAL
 GOVBAL
 TINSDEF.TINS
 TFLABDEF.TFLAB
 TFINDEF
 MPCDEF.MPC
 SAVINVBAL
 TABSEQ
 INVABEQ
 GDABEQ


 /
 ;
MODEL NLPCGE /




*Price block===============================================
 PMDEF
 PEDEF
 PQDEF
 PXDEF
 PADEF
 PLEODEF
 PASDEF
 PSCDEF
 PSUBDEF
 CPIDEF


*Production block=========================================
 LEOAGGINT
 LEOAGGSUB
 CESQSCPRD
 CESSUBPRD
 CESSUBIPRD
 CESCGAPRD

 CESCAPPRD
 CESLABPRD
 CESQSCFOC
 CESLABFOC
 CESLANDFOC

 CESCAPFOC
 CESSUBFOC
 CESSUBPRD2
 CESSUBIFOC
 CESCGAFOC
 QINTAGG
 INTDEM
 DOMPROD


*Investement block=========================================

 GRPROFDEF
 GRRENTDEF
 INVDEM
 PIDEF
 QAGGINVDEF



*Trade block ==============================================
 CET
 CET2
 ESUPPLY
 ARMINGTON
 COSTMIN
 ARMINGTON2

*Trade margins block ======================================
 QTDEM
 TMEQ
 TMIEQ
 FTMDEF
 FTMINVDEF
*Institution block ========================================
 YFLABDEF
 YFINDEF
 YIFLDEF
 YIFINDEF
 YHDEF
 WEALTHDEF
 EHDEF
 HADEM
 CESCGH
 HMDEM
 GOVDEM
 PERMITEQ
 EGDEF
 YGDEF

*System constraint block===================================
 COMEQUILTR
 COMEQUILNTR
 FACEQUIL
 CURACCBAL
 GOVBAL
 TINSDEF
 TFLABDEF
 TFINDEF
 MPCDEF
 SAVINVBAL
 OBJEQ
 TABSEQ
 INVABEQ
 GDABEQ


 /
 ;



*12. FIXING VARIABLES NOT IN MODEL AT ZERO ##########################


  PDS.FX(C)$(NOT CD(C)) = 0;
  PE.FX(C)$(NOT CE(C)) = 0;
  PM.FX(C)$(NOT CM(C)) = 0;
  PX.FX(C)$(NOT CX(C)) = 0;
  PSUBI.FX(A)$( SUM(CSUBI, SAM(CSUBI,A))= 0)= 0;

  QD.FX(C)$(NOT CD(C)) = 0;
  QE.FX(C)$(NOT CE(C)) = 0;
  QF.FX(F,A)$(NOT SAM(F,A)) = 0;
  QG.FX(C)$(NOT CGOV(C)) = 0;
  QH.FX(H,C,CGH)$(NOT usehcdef(C,CGH)*SAM(C,H)) = 0;
  QINTA.FX(CSUBI,A,CGA)$(NOT QINTA0(CSUBI,A,CGA)) = 0;
  QSUBI.FX(A)$( SUM(CSUBI, SAM(CSUBI,A))= 0)= 0;


  QINT.FX(C,A)$(NOT SAM(C,A)) = 0;
  QINV.FX(C,A,FCAP)$(qbarinv(C,A,FCAP)=0 ) = 0;
  QM.FX(C)$(NOT CM(C)) = 0;
  QQ.FX(C)$(NOT (CD(C) OR CM(C))) = 0;
  QT.FX(C)$(NOT CTR(C)) = 0;
  TM.FX(C,PNI)$(trq(C,PNI) = 0)=0;
  TMI.FX(C,A)$(trqi(C,A) = 0)=0;
  FTM.FX(C,PNI)$(ftmq(C,PNI) = 0)=0;
  FTMINV.FX(C,A)$(ftmqinv(C,A) = 0)=0;
  QX.FX(C)$(NOT CX(C)) = 0;
  PI.FX(A,FCAP)$(PI0(A,FCAP) = 0) = 0 ;
  QAGGINV.FX(A,FCAP)$(QAGGINV0(A,FCAP) = 0) = 0 ;

  YIFL.FX(INSD,FLAB)$(NOT SAM(INSD,FLAB)) = 0;
  YIFIN.FX(INSD)$(NOT SAM(INSD,'STOCK')) = 0;

*13. MODEL CLOSURE ##################################################
$ontext
In the simulation file, SAINTSIM.GMS, the user chooses between
alternative closures. Those choices take precedence over the choices
made in this file.

In the following segment, closures is selected for the base model
solution in this file. The clearing variables for micro and macro
constraints are as follows:

FACEQUIL - WF: for each factor, the economywide wage is the
market-clearing variable in a setting with perfect factor mobility across
activities.

CURACCBAL - EXR: a flexible exchange rate clears the current account of
the RoW.

GOVBAL - GSAV: flexible government savings clears the government
account.

SAVINVBAL - SADJ: the savings rates of domestic institutions are scaled
to generate enough savings to finance exogenous investment quantities
(investment-driven savings).

The CPI is the model numeraire.
$offtext

*Factor markets=======

  QFS.FX(F)       = QFS0(F);
  WF.LO(F)        = -inf;
  WF.UP(F)        = +inf;
  WFDIST.FX(F,A)  = WFDIST0(F,A);
* WFDIST.LO(F,A)  = -INF;
* WFDIST.UP(F,A)  = +INF;



*Current account of RoW===========
 FSAV.FX      = FSAV0;

if( SUM(AC, SAM('ROW',AC)) = 0,


 EXR.FX       = EXR0;
 );
*Import and export prices (in FCU) are fixed. A change in model
*specification is required if these prices are to be endogenous.
  PWM.FX(C)    = PWM0(C) ;
  PWE.FX(C)    = PWE0(C) ;


*Current government balance=======

*GSAV.FX     = GSAV0 ;
 TINSADJ.FX  = TINSADJ0;
 TLABADJ.FX  = TLABADJ0;
 TFINADJ.FX  = TFINADJ0;
 DTINS.FX    = DTINS0;
 GADJ.FX     = GADJ0;
 IADJM.FX    = IADJM0;
*GOVSHR.FX   = GOVSHR0 ;


*Savings-investment balance=======

 MPCADJ.FX = MPCADJ0;
* DMPC.FX   = DMPC0;
 IADJ.FX(A,FCAP)   = IADJ0(A,FCAP);
*INVSHR.FX = INVSHR0 ;


*Numeraire price index============

 CPI.FX        = CPI0;



*14. SOLUTION STATEMENT #############################################

OPTIONS ITERLIM = 1000, LIMROW = 4000, LIMCOL = 3, SOLPRINT=ON ;

$ontext
These options are useful for debugging. When checking whether the
initial data represent a solution, set LIMROW to a value greater than
the number of equations and search for three asterisks in the listing
file. SOLPRINT=ON provides a complete listing file. The program also
has a number of display statements, so when running experiments it is
usually not necessary to provide a solution print as well.
$offtext

 MCPCGE.HOLDFIXED   = 1 ;
 MCPCGE.TOLINFREP   = .0001 ;


$ontext
The HOLDFIXED option converts all variables which are fixed (.FX) into
parameters. They are then not solved as part of the model.
The TOLINFREP parameter sets the tolerance for determinining whether
initial values of variables represent a solution of the model
equations. Whether these initial equation values are printed is
determimed by the LIMROW option. Equations which are not satsfied to
the degree TOLINFREP are printed with three asterisks next to their
listing.
$offtext



*Solve statements


if(SOLVERCHOICE        = 1,
 SOLVE MCPCGE USING MCP ;
);




if(SOLVERCHOICE        = 2,
 SOLVE NLPCGE USING NLP MINIMIZING WALRASSQR;
);

*15. SOLUTION REPORTS ###############################################

*Include file defining report parameters summarizing economic
*data for the base year.

$INCLUDE REPBASE.INC


*Creation of EXCEL reports. Put a star in front of thoose reports you do not want


*$libinclude xldump GDPBASE GDPBASE.XLS GDPBASE!


$libinclude xldump MICROSAM MICROSAM.XLS MICROSAM!

*$libinclude xldump MACROSAM MACROSAM.XLS MACROSAM!


*$libinclude xldump FACTAB1 FACTAB.XLS FACTAB1!
*$libinclude xldump FACTAB2 FACTAB.XLS FACTAB2!
*$libinclude xldump FACTAB3 FACTAB.XLS FACTAB3!
*$libinclude xldump FACTAB4 FACTAB.XLS FACTAB4!

*This report gives the share of item ACP in the total income of hhd H (%)
*$libinclude xldump HHDTAB1 HHDTAB.XLS HHDTAB1!
*This report gives the share of hhd AC in total hhd income from item ACP (%)
*$libinclude xldump HHDTAB2 HHDTAB.XLS HHDTAB2!





 MCPCGE.MODELSTAT = 0;
 MCPCGE.SOLVESTAT = 0;
 MCPCGE.NUMREDEF  = 0;

 NLPCGE.MODELSTAT = 0;
 NLPCGE.SOLVESTAT = 0;
 NLPCGE.NUMREDEF  = 0;


*#*#*#*#*# THE END OF SAINTBASE.GMS #*#*#*#*
